local ALName, ALPrivate = ...

local AtlasLoot = _G.AtlasLoot
local VendorPrice = {}
AtlasLoot.Data.VendorPrice = VendorPrice
local AL = AtlasLoot.Locales

local PRICE_INFO_LIST = {
	--- Classic
	-- items
	["burningblossom"] 	= { itemID = 23247 }, -- Burning Blossom
	["ancestrycoin"] 	= { itemID = 21100 }, -- Coin of Ancestry

	-- others
	["money"] 			= { func = GetCoinTextureString },

	--- BC
	["holydust"] = { itemID = 29735 }, -- Holy Dust (Aldor)
	["arcanerune"] = { itemID = 29736 }, -- Holy Dust (Scryers)
	["SpiritShard"] = { itemID = 28558 }, -- Spirit Shard
	["HalaaRT"] = { itemID = 26044 }, -- Halaa Research Token
	["HalaaBT"] = { itemID = 26045 }, -- Halaa Battle Token
	["MarkOfThrallmar"] = { itemID = 24581 }, -- Mark of Thrallmar
	["MarkOfHonorHold"] = { itemID = 24579 }, -- Mark of Honor Hold
	["BoJ"] = { itemID = 29434 }, -- Badge of Justice
	["glowcap"] = { itemID = 24245 }, -- Glowcap
	["ApexisC"] = { itemID = 32572 }, -- Apexis Crystal
	["ApexisS"] = { itemID = 32569 }, -- Apexis Shard
	["Brewfest"] = { itemID = 37829 }, -- Brewfest Prize Token
    ["sunmote"] = { itemID = 34664 }, -- Sunmote
	-- pvp
	["honor"] = { currencyID = 1901 }, -- Honor
	["arena"] = { currencyID = 1900 },  -- Arena
	--["honorH"] = { currencyID = 1901 }, -- Honor / Horde
	--["honorA"] = { currencyID = 1901 }, -- Honor / Alli
	["pvpAlterac"] = { itemID = 20560 }, -- Alterac Valley Mark of Honor
	["pvpWarsong"] = { itemID = 20558 }, -- Warsong Gulch Mark of Honor
	["pvpArathi"] = { itemID = 20559 }, -- Arathi Basin Mark of Honor
	["pvpEye"] = { itemID = 29024 }, -- Eye of the Storm Mark of Honor

    --- Wrath
    ["championsSeal"] = { currencyID = 241 }, -- Champion's Seal

    ["EmblemOfHeroism"] = { currencyID = 101 }, -- Emblem of Heroism
    ["EmblemOfValor"] = { currencyID = 102 }, -- Emblem of Valor
    ["EmblemOfTriumph"] = { currencyID = 301 }, -- Emblem of Triumph
    ["EmblemOfConquest"] = { currencyID = 221 }, -- Emblem of Conquest
    ["EmblemOfFrost"] = { currencyID = 341 }, -- Emblem of Frost

    ["cpvpAlterac"] = { currencyID = 121 }, -- Alterac Valley Mark of Honor
	["cpvpWarsong"] = { currencyID = 125 }, -- Warsong Gulch Mark of Honor
	["cpvpArathi"] = { currencyID = 122 }, -- Arathi Basin Mark of Honor
	["cpvpEye"] = { currencyID = 123 }, -- Eye of the Storm Mark of Honor
	["cpvpWintergrasp"] = { currencyID = 126 }, -- Wintergrasp Mark of Honor
	["cpvpIsle"] = { currencyID = 321 }, -- Isle of Conquest Mark of Honor
	["cpvpStrand"] = { currencyID = 124 }, -- Strand of the Ancients Mark of Honor
}

local VENDOR_PRICE_FORMAT = {}
for k, v in pairs(PRICE_INFO_LIST) do
    if v.itemID then
        VENDOR_PRICE_FORMAT[v.itemID] = k..":%d"
    elseif v.currencyID and C_CurrencyInfo and C_CurrencyInfo.GetCurrencyInfo then
        local currencyInfo = C_CurrencyInfo.GetCurrencyInfo(v.currencyID)
        if currencyInfo and currencyInfo.iconFileID then
            VENDOR_PRICE_FORMAT[currencyInfo.iconFileID] = k..":%d"
        end
    end
end

-- updated with script
local VENDOR_PRICES_AUTO, VENDOR_PRICES_AUTO_RAW = AtlasLoot:GetGameVersionDataTable()
VENDOR_PRICES_AUTO_RAW.CLASSIC = {

}

if AtlasLoot:GameVersion_GE(AtlasLoot.BC_VERSION_NUM) then
    VENDOR_PRICES_AUTO_RAW.BCC = {
        [187049] = "money:152000",
        [187048] = "money:152000",
        [185924] = "money:144000",
        [185923] = "money:144000",
        [185690] = "money:80000",
        [39477] = "Brewfest:5",
        [39476] = "Brewfest:5",
        [38628] = "money:400000",
        [38550] = "arena:500",
        [38549] = "arena:500",
        [38548] = "arena:500",
        [38547] = "arena:500",
        [38546] = "arena:500",
        [38545] = "arena:500",
        [38229] = "glowcap:25",
        [37929] = "honor:15300:pvpEye:5",
        [37928] = "honor:15300:pvpEye:5",
        [37927] = "honor:15300:pvpAlterac:10",
        [37864] = "honor:40000",
        [37816] = "Brewfest:20",
        [37750] = "Brewfest:2",
        [37737] = "Brewfest:200",
        [37736] = "Brewfest:200",
        [36737] = "arena:650",
        [35906] = "pvpAlterac:30:pvpArathi:30:pvpWarsong:30",
        [35415] = "money:272224",
        [35408] = "money:145302",
        [35403] = "money:127598",
        [35394] = "money:259883",
        [35387] = "money:123397",
        [35385] = "money:184540",
        [35379] = "money:226822",
        [35374] = "money:149973",
        [35367] = "money:146143",
        [35365] = "money:201430",
        [35358] = "money:202894",
        [35347] = "money:164580",
        [35342] = "money:173807",
        [35336] = "money:127597",
        [35329] = "money:104726",
        [35327] = "honor:30000:pvpAlterac:20",
        [35326] = "BoJ:75",
        [35324] = "BoJ:60",
        [35321] = "BoJ:60",
        [35320] = "honor:7650",
        [35319] = "honor:15300:pvpEye:5",
        [35317] = "honor:15300:pvpEye:5",
        [35178] = "honor:11794:pvpWarsong:20",
        [35177] = "honor:11794:pvpWarsong:20",
        [35176] = "honor:11794:pvpWarsong:20",
        [35175] = "honor:11794:pvpWarsong:20",
        [35173] = "honor:11794:pvpWarsong:20",
        [35172] = "honor:11794:pvpWarsong:20",
        [35170] = "honor:11794:pvpWarsong:20",
        [35166] = "honor:11794:pvpWarsong:20",
        [35163] = "honor:17850:pvpArathi:20",
        [35162] = "honor:17850:pvpArathi:20",
        [35161] = "honor:17850:pvpArathi:20",
        [35160] = "honor:17850:pvpArathi:20",
        [35158] = "honor:17850:pvpArathi:20",
        [35157] = "honor:17850:pvpArathi:20",
        [35155] = "honor:17850:pvpArathi:20",
        [35151] = "honor:17850:pvpArathi:20",
        [35148] = "honor:17850:pvpEye:40",
        [35147] = "honor:17850:pvpEye:40",
        [35146] = "honor:17850:pvpEye:40",
        [35145] = "honor:17850:pvpEye:40",
        [35143] = "honor:17850:pvpEye:40",
        [35142] = "honor:17850:pvpEye:40",
        [35140] = "honor:17850:pvpEye:40",
        [35136] = "honor:17850:pvpEye:40",
        [35135] = "honor:15300:pvpEye:5",
        [35134] = "honor:15300:pvpEye:5",
        [35133] = "honor:15300:pvpEye:5",
        [35132] = "honor:15300:pvpEye:5",
        [35131] = "honor:15300:pvpAlterac:10",
        [35130] = "honor:15300:pvpAlterac:10",
        [35129] = "honor:15300:pvpAlterac:10",
        [35110] = "arena:650",
        [35109] = "arena:3750",
        [35108] = "arena:1000",
        [35107] = "arena:1000",
        [35103] = "arena:3750",
        [35102] = "arena:3150",
        [35101] = "arena:2625",
        [35095] = "arena:1125",
        [35094] = "arena:1875",
        [35093] = "arena:2625",
        [35082] = "arena:3150",
        [35076] = "arena:2625",
        [35075] = "arena:3750",
        [35074] = "arena:1125",
        [35073] = "arena:1875",
        [35072] = "arena:1125",
        [35071] = "arena:2625",
        [35065] = "arena:1000",
        [35064] = "arena:3750",
        [35058] = "arena:1125",
        [35047] = "arena:3750",
        [35038] = "arena:1125",
        [35037] = "arena:1125",
        [35018] = "arena:3750",
        [35017] = "arena:1125",
        [35016] = "arena:1125",
        [35015] = "arena:3750",
        [35014] = "arena:3150",
        [35008] = "arena:1125",
        [34997] = "arena:3750",
        [34996] = "arena:2625",
        [34995] = "arena:1125",
        [34994] = "arena:1500",
        [34993] = "arena:1875",
        [34992] = "arena:1875",
        [34991] = "arena:1125",
        [34990] = "arena:1875",
        [34989] = "arena:3750",
        [34988] = "arena:1125",
        [34987] = "arena:3750",
        [34986] = "arena:1875",
        [34985] = "arena:1000",
        [34580] = "honor:30000:pvpAlterac:20",
        [34579] = "honor:30000:pvpAlterac:20",
        [34578] = "honor:30000:pvpAlterac:20",
        [34577] = "honor:30000:pvpAlterac:20",
        [34576] = "honor:30000:pvpAlterac:20",
        [34540] = "arena:3750",
        [34530] = "arena:3750",
        [34529] = "arena:3750",
        [34478] = "glowcap:30",
        [34175] = "money:144000",
        [34174] = "money:152000",
        [34173] = "money:144000",
        [34172] = "money:152000",
        [34163] = "BoJ:75",
        [34162] = "BoJ:75",
        [34129] = "pvpAlterac:30:pvpArathi:30:pvpWarsong:30",
        [34066] = "arena:1000",
        [34059] = "arena:1000",
        [34050] = "BoJ:75",
        [34049] = "BoJ:75",
        [34033] = "arena:1125",
        [34028] = "Brewfest:600",
        [34016] = "arena:1125",
        [34015] = "arena:1125",
        [34014] = "arena:1000",
        [34008] = "Brewfest:100",
        [33999] = "money:16000000",
        [33978] = "Brewfest:600",
        [33974] = "BoJ:60",
        [33973] = "BoJ:60",
        [33972] = "BoJ:75",
        [33970] = "BoJ:60",
        [33969] = "Brewfest:50",
        [33968] = "Brewfest:50",
        [33967] = "Brewfest:50",
        [33966] = "Brewfest:100",
        [33965] = "BoJ:75",
        [33953] = "arena:1000",
        [33952] = "arena:1000",
        [33951] = "honor:5897",
        [33950] = "arena:1000",
        [33949] = "arena:1000",
        [33948] = "honor:5897",
        [33947] = "arena:1000",
        [33946] = "arena:1000",
        [33945] = "honor:5897",
        [33944] = "arena:1000",
        [33943] = "arena:1000",
        [33942] = "honor:5897",
        [33941] = "arena:1000",
        [33940] = "arena:1000",
        [33939] = "honor:5897",
        [33938] = "arena:1000",
        [33937] = "arena:1000",
        [33936] = "honor:5897",
        [33935] = "money:3400:ApexisS:50",
        [33934] = "money:3400:ApexisS:50",
        [33927] = "Brewfest:100",
        [33923] = "honor:15300:pvpEye:5",
        [33922] = "honor:15300:pvpEye:5",
        [33921] = "honor:15300:pvpEye:5",
        [33920] = "honor:15300:pvpEye:5",
        [33919] = "honor:7650",
        [33918] = "honor:7650",
        [33917] = "honor:11794:pvpWarsong:10",
        [33916] = "honor:17850:pvpEye:20",
        [33915] = "honor:17850:pvpArathi:20",
        [33914] = "honor:17850:pvpEye:20",
        [33913] = "honor:11794:pvpWarsong:10",
        [33912] = "honor:17850:pvpArathi:20",
        [33911] = "honor:17850:pvpEye:20",
        [33910] = "honor:11794:pvpWarsong:10",
        [33909] = "honor:17850:pvpArathi:20",
        [33908] = "honor:17850:pvpEye:20",
        [33907] = "honor:17850:pvpArathi:20",
        [33906] = "honor:11794:pvpWarsong:10",
        [33905] = "honor:17850:pvpEye:20",
        [33904] = "honor:11794:pvpWarsong:10",
        [33903] = "honor:17850:pvpArathi:20",
        [33902] = "honor:17850:pvpEye:20",
        [33901] = "honor:11794:pvpWarsong:10",
        [33900] = "honor:17850:pvpArathi:20",
        [33899] = "honor:17850:pvpEye:20",
        [33898] = "honor:17850:pvpArathi:20",
        [33897] = "honor:11794:pvpWarsong:10",
        [33896] = "honor:17850:pvpEye:20",
        [33895] = "honor:17850:pvpArathi:20",
        [33894] = "honor:11794:pvpWarsong:10",
        [33893] = "honor:11794:pvpWarsong:10",
        [33892] = "honor:17850:pvpEye:20",
        [33891] = "honor:17850:pvpArathi:20",
        [33890] = "honor:17850:pvpEye:20",
        [33889] = "honor:11794:pvpWarsong:10",
        [33888] = "honor:17850:pvpArathi:20",
        [33887] = "honor:11794:pvpWarsong:10",
        [33886] = "honor:17850:pvpEye:20",
        [33885] = "honor:17850:pvpArathi:20",
        [33884] = "honor:17850:pvpEye:20",
        [33883] = "honor:11794:pvpWarsong:10",
        [33882] = "honor:17850:pvpArathi:20",
        [33881] = "honor:11794:pvpWarsong:10",
        [33880] = "honor:17850:pvpEye:20",
        [33879] = "honor:17850:pvpArathi:20",
        [33878] = "honor:17850:pvpEye:20",
        [33877] = "honor:17850:pvpArathi:20",
        [33876] = "honor:11794:pvpWarsong:10",
        [33868] = "Brewfest:100",
        [33864] = "Brewfest:50",
        [33863] = "Brewfest:200",
        [33862] = "Brewfest:200",
        [33853] = "honor:7650",
        [33843] = "arena:1000",
        [33842] = "arena:1000",
        [33841] = "arena:1000",
        [33832] = "BoJ:75",
        [33813] = "honor:11794:pvpWarsong:10",
        [33812] = "honor:17850:pvpEye:20",
        [33811] = "honor:17850:pvpArathi:20",
        [33810] = "BoJ:75",
        [33801] = "arena:1125",
        [33771] = "arena:1875",
        [33770] = "arena:1500",
        [33769] = "arena:1875",
        [33768] = "arena:1875",
        [33767] = "arena:1125",
        [33766] = "arena:3750",
        [33765] = "arena:1000",
        [33764] = "arena:1000",
        [33763] = "arena:3150",
        [33762] = "arena:2625",
        [33761] = "arena:1875",
        [33760] = "arena:1875",
        [33759] = "arena:1125",
        [33758] = "arena:1875",
        [33757] = "arena:1500",
        [33756] = "arena:1125",
        [33755] = "arena:1875",
        [33754] = "arena:2625",
        [33753] = "arena:1500",
        [33752] = "arena:1875",
        [33751] = "arena:1875",
        [33750] = "arena:1125",
        [33749] = "arena:1875",
        [33748] = "arena:1875",
        [33747] = "arena:1500",
        [33746] = "arena:1875",
        [33745] = "arena:1875",
        [33744] = "arena:1125",
        [33743] = "arena:3150",
        [33742] = "arena:1500",
        [33741] = "arena:1875",
        [33740] = "arena:1875",
        [33739] = "arena:1125",
        [33738] = "arena:1875",
        [33737] = "arena:2625",
        [33736] = "arena:1125",
        [33735] = "arena:1875",
        [33734] = "arena:1125",
        [33733] = "arena:2625",
        [33732] = "arena:1500",
        [33731] = "arena:1875",
        [33730] = "arena:1875",
        [33729] = "arena:1125",
        [33728] = "arena:1875",
        [33727] = "arena:3750",
        [33726] = "arena:1500",
        [33725] = "arena:1875",
        [33724] = "arena:1875",
        [33723] = "arena:1125",
        [33722] = "arena:1875",
        [33721] = "arena:1875",
        [33720] = "arena:1500",
        [33719] = "arena:1875",
        [33718] = "arena:1875",
        [33717] = "arena:1125",
        [33716] = "arena:3750",
        [33715] = "arena:1500",
        [33714] = "arena:1875",
        [33713] = "arena:1875",
        [33712] = "arena:1125",
        [33711] = "arena:1875",
        [33710] = "arena:1500",
        [33709] = "arena:1875",
        [33708] = "arena:1875",
        [33707] = "arena:1125",
        [33706] = "arena:1875",
        [33705] = "arena:1125",
        [33704] = "arena:1875",
        [33703] = "arena:1500",
        [33702] = "arena:1875",
        [33701] = "arena:1875",
        [33700] = "arena:1125",
        [33699] = "arena:1500",
        [33698] = "arena:1875",
        [33697] = "arena:1875",
        [33696] = "arena:1125",
        [33695] = "arena:1875",
        [33694] = "arena:1875",
        [33693] = "arena:1500",
        [33692] = "arena:1875",
        [33691] = "arena:1875",
        [33690] = "arena:1125",
        [33689] = "arena:1125",
        [33688] = "arena:3750",
        [33687] = "arena:3150",
        [33686] = "arena:1875",
        [33685] = "arena:1875",
        [33684] = "arena:1125",
        [33683] = "arena:1875",
        [33682] = "arena:1500",
        [33681] = "arena:1125",
        [33680] = "arena:1875",
        [33679] = "arena:1500",
        [33678] = "arena:1875",
        [33677] = "arena:1875",
        [33676] = "arena:1125",
        [33675] = "arena:1875",
        [33674] = "arena:1500",
        [33673] = "arena:1875",
        [33672] = "arena:1875",
        [33671] = "arena:1125",
        [33670] = "arena:3750",
        [33669] = "arena:2625",
        [33668] = "arena:1500",
        [33667] = "arena:1875",
        [33666] = "arena:1875",
        [33665] = "arena:1125",
        [33664] = "arena:1875",
        [33663] = "arena:3750",
        [33662] = "arena:1125",
        [33661] = "arena:1875",
        [33593] = "BoJ:35",
        [33589] = "BoJ:35",
        [33588] = "BoJ:35",
        [33587] = "BoJ:60",
        [33586] = "BoJ:60",
        [33585] = "BoJ:75",
        [33584] = "BoJ:75",
        [33583] = "BoJ:60",
        [33582] = "BoJ:60",
        [33580] = "BoJ:35",
        [33579] = "BoJ:75",
        [33578] = "BoJ:35",
        [33577] = "BoJ:60",
        [33566] = "BoJ:75",
        [33559] = "BoJ:60",
        [33557] = "BoJ:35",
        [33552] = "BoJ:75",
        [33540] = "BoJ:35",
        [33539] = "BoJ:60",
        [33538] = "BoJ:75",
        [33537] = "BoJ:60",
        [33536] = "BoJ:60",
        [33535] = "BoJ:35",
        [33534] = "BoJ:60",
        [33532] = "BoJ:35",
        [33531] = "BoJ:60",
        [33530] = "BoJ:75",
        [33529] = "BoJ:35",
        [33528] = "BoJ:60",
        [33527] = "BoJ:75",
        [33524] = "BoJ:60",
        [33523] = "BoJ:60",
        [33522] = "BoJ:75",
        [33520] = "BoJ:35",
        [33519] = "BoJ:60",
        [33518] = "BoJ:75",
        [33517] = "BoJ:60",
        [33516] = "BoJ:35",
        [33515] = "BoJ:75",
        [33514] = "BoJ:60",
        [33513] = "BoJ:35",
        [33512] = "BoJ:60",
        [33510] = "BoJ:20",
        [33509] = "BoJ:20",
        [33508] = "BoJ:20",
        [33507] = "BoJ:20",
        [33506] = "BoJ:20",
        [33505] = "BoJ:20",
        [33504] = "BoJ:20",
        [33503] = "BoJ:20",
        [33502] = "BoJ:20",
        [33501] = "BoJ:75",
        [33484] = "BoJ:60",
        [33386] = "BoJ:60",
        [33334] = "BoJ:35",
        [33333] = "BoJ:60",
        [33331] = "BoJ:60",
        [33325] = "BoJ:35",
        [33324] = "BoJ:60",
        [33313] = "honor:15000",
        [33309] = "honor:15000",
        [33304] = "BoJ:60",
        [33296] = "BoJ:35",
        [33291] = "BoJ:60",
        [33287] = "BoJ:60",
        [33280] = "BoJ:60",
        [33279] = "BoJ:60",
        [33222] = "BoJ:60",
        [33207] = "BoJ:60",
        [33192] = "BoJ:25",
        [33149] = "money:80000",
        [33078] = "arena:1000",
        [33077] = "arena:1000",
        [33076] = "arena:1000",
        [33068] = "honor:15300:pvpEye:5",
        [33067] = "honor:15300:pvpEye:5",
        [33066] = "honor:15300:pvpEye:5",
        [33065] = "honor:15300:pvpEye:5",
        [33064] = "honor:15300:pvpAlterac:5",
        [33057] = "honor:15300:pvpAlterac:5",
        [33056] = "honor:15300:pvpAlterac:5",
        [33047] = "Brewfest:100",
        [33006] = "arena:3750",
        [32999] = "honor:17850:pvpEye:20",
        [32998] = "honor:17850:pvpArathi:20",
        [32997] = "honor:11794:pvpWarsong:10",
        [32990] = "honor:17850:pvpEye:20",
        [32989] = "honor:11794:pvpWarsong:10",
        [32988] = "honor:17850:pvpArathi:20",
        [32981] = "honor:17850:pvpEye:20",
        [32980] = "honor:11794:pvpWarsong:10",
        [32979] = "honor:17850:pvpArathi:20",
        [32978] = "honor:8925",
        [32977] = "honor:5897",
        [32976] = "honor:8925",
        [32975] = "honor:8925",
        [32974] = "honor:8925",
        [32973] = "honor:5897",
        [32964] = "honor:17786",
        [32963] = "honor:17786",
        [32962] = "honor:5897",
        [32961] = "honor:9000",
        [32948] = "SpiritShard:2",
        [32947] = "SpiritShard:2",
        [32828] = "ApexisS:10",
        [32821] = "honor:11794:pvpWarsong:10",
        [32820] = "honor:11794:pvpWarsong:10",
        [32819] = "honor:11794:pvpWarsong:10",
        [32818] = "honor:11794:pvpWarsong:10",
        [32817] = "honor:11794:pvpWarsong:10",
        [32816] = "honor:11794:pvpWarsong:10",
        [32814] = "honor:11794:pvpWarsong:10",
        [32813] = "honor:11794:pvpWarsong:10",
        [32812] = "honor:11794:pvpWarsong:10",
        [32811] = "honor:11794:pvpWarsong:10",
        [32810] = "honor:11794:pvpWarsong:10",
        [32809] = "honor:11794:pvpWarsong:10",
        [32808] = "honor:17850:pvpArathi:20",
        [32807] = "honor:17850:pvpArathi:20",
        [32806] = "honor:17850:pvpArathi:20",
        [32805] = "honor:17850:pvpArathi:20",
        [32804] = "honor:17850:pvpArathi:20",
        [32803] = "honor:17850:pvpArathi:20",
        [32802] = "honor:17850:pvpArathi:20",
        [32801] = "honor:17850:pvpArathi:20",
        [32800] = "honor:17850:pvpArathi:20",
        [32799] = "honor:17850:pvpArathi:20",
        [32798] = "honor:17850:pvpArathi:20",
        [32797] = "honor:17850:pvpArathi:20",
        [32796] = "honor:17850:pvpEye:20",
        [32795] = "honor:17850:pvpEye:20",
        [32794] = "honor:17850:pvpEye:20",
        [32793] = "honor:17850:pvpEye:20",
        [32792] = "honor:17850:pvpEye:20",
        [32791] = "honor:17850:pvpEye:20",
        [32790] = "honor:17850:pvpEye:20",
        [32789] = "honor:17850:pvpEye:20",
        [32788] = "honor:17850:pvpEye:20",
        [32787] = "honor:17850:pvpEye:20",
        [32786] = "honor:17850:pvpEye:20",
        [32785] = "honor:17850:pvpEye:20",
        [32784] = "ApexisS:2",
        [32783] = "ApexisS:3",
        [32771] = "money:41230",
        [32770] = "money:41230",
        [32722] = "money:4000",
        [32721] = "money:4500",
        [32654] = "ApexisC:1:ApexisS:50",
        [32653] = "ApexisC:1:ApexisS:50",
        [32652] = "ApexisC:1:ApexisS:50",
        [32651] = "ApexisC:4:ApexisS:100",
        [32650] = "ApexisC:1:ApexisS:50",
        [32648] = "ApexisC:4:ApexisS:100",
        [32647] = "ApexisC:4:ApexisS:100",
        [32645] = "ApexisC:4:ApexisS:100",
        [32539] = "money:138166",
        [32538] = "money:137691",
        [32455] = "money:1080:honor:1",
        [32453] = "money:2000:honor:2",
        [32452] = "honor:9000",
        [32451] = "honor:17786",
        [32450] = "honor:17786",
        [32445] = "money:10000",
        [32319] = "money:2000000",
        [32318] = "money:2000000",
        [32317] = "money:2000000",
        [32316] = "money:2000000",
        [32314] = "money:2000000",
        [32233] = "money:5000",
        [32090] = "BoJ:50",
        [32089] = "BoJ:50",
        [32088] = "BoJ:50",
        [32087] = "BoJ:50",
        [32086] = "BoJ:50",
        [32085] = "BoJ:50",
        [32084] = "BoJ:50",
        [32083] = "BoJ:50",
        [32070] = "money:32000",
        [32060] = "arena:1875",
        [32059] = "arena:1500",
        [32058] = "arena:1875",
        [32057] = "arena:1875",
        [32056] = "arena:1125",
        [32055] = "honor:19125",
        [32054] = "honor:5897",
        [32053] = "honor:17786",
        [32052] = "honor:14228",
        [32051] = "arena:1875",
        [32050] = "arena:1875",
        [32049] = "arena:1125",
        [32048] = "arena:1875",
        [32047] = "arena:1500",
        [32046] = "honor:9000",
        [32045] = "honor:15000",
        [32044] = "honor:14228",
        [32043] = "arena:1500",
        [32042] = "arena:1875",
        [32041] = "arena:1875",
        [32040] = "arena:1125",
        [32039] = "arena:1875",
        [32038] = "arena:1875",
        [32037] = "arena:1500",
        [32036] = "arena:1875",
        [32035] = "arena:1875",
        [32034] = "arena:1125",
        [32033] = "arena:1500",
        [32032] = "arena:1875",
        [32031] = "arena:1875",
        [32030] = "arena:1125",
        [32029] = "arena:1875",
        [32028] = "honor:14228",
        [32027] = "honor:9000",
        [32026] = "honor:14228",
        [32025] = "honor:19125",
        [32024] = "arena:1500",
        [32023] = "arena:1875",
        [32022] = "arena:1875",
        [32021] = "arena:1125",
        [32020] = "arena:1875",
        [32019] = "arena:1875",
        [32018] = "arena:1500",
        [32017] = "arena:1875",
        [32016] = "arena:1875",
        [32015] = "arena:1125",
        [32014] = "honor:19125",
        [32013] = "arena:1500",
        [32012] = "arena:1875",
        [32011] = "arena:1875",
        [32010] = "arena:1125",
        [32009] = "arena:1875",
        [32008] = "arena:1500",
        [32007] = "arena:1875",
        [32006] = "arena:1875",
        [32005] = "arena:1125",
        [32004] = "arena:1875",
        [32003] = "honor:9000",
        [32002] = "arena:1875",
        [32001] = "arena:1500",
        [32000] = "arena:1875",
        [31999] = "arena:1875",
        [31998] = "arena:1125",
        [31997] = "arena:1875",
        [31996] = "arena:1500",
        [31995] = "arena:1875",
        [31993] = "arena:1125",
        [31992] = "arena:1875",
        [31991] = "arena:1875",
        [31990] = "arena:1500",
        [31989] = "arena:1875",
        [31988] = "arena:1875",
        [31987] = "arena:1125",
        [31986] = "honor:19125",
        [31985] = "honor:9000",
        [31984] = "honor:19125",
        [31983] = "arena:1875",
        [31982] = "arena:1875",
        [31981] = "arena:1125",
        [31980] = "arena:1875",
        [31979] = "arena:1500",
        [31978] = "honor:9000",
        [31977] = "arena:1875",
        [31976] = "arena:1500",
        [31975] = "arena:1875",
        [31974] = "arena:1875",
        [31973] = "arena:1125",
        [31972] = "arena:1875",
        [31971] = "arena:1500",
        [31969] = "arena:1875",
        [31968] = "arena:1875",
        [31967] = "arena:1125",
        [31966] = "honor:19125",
        [31965] = "honor:14228",
        [31964] = "arena:1500",
        [31963] = "arena:1875",
        [31962] = "arena:1875",
        [31961] = "arena:1125",
        [31960] = "arena:1875",
        [31959] = "honor:19125",
        [31958] = "honor:9000",
        [31949] = "money:4000",
        [31855] = "money:3200:honor:50",
        [31854] = "pvpEye:2",
        [31853] = "money:3200:honor:50",
        [31852] = "pvpEye:2",
        [31841] = "pvpAlterac:2",
        [31840] = "pvpArathi:2",
        [31839] = "pvpAlterac:2",
        [31838] = "pvpArathi:2",
        [31836] = "money:630000",
        [31835] = "money:665000",
        [31834] = "money:630000",
        [31833] = "money:665000",
        [31832] = "money:630000",
        [31831] = "money:665000",
        [31830] = "money:630000",
        [31829] = "money:665000",
        [31804] = "money:8000",
        [31775] = "glowcap:10",
        [31774] = "money:9000",
        [31773] = "money:9500",
        [31650] = "honor:6311",
        [31649] = "honor:10328",
        [31648] = "honor:10328",
        [31647] = "honor:6311",
        [31646] = "honor:10328",
        [31644] = "honor:3156",
        [31643] = "honor:5021",
        [31642] = "honor:5021",
        [31641] = "honor:3156",
        [31640] = "honor:5164",
        [31639] = "honor:6311",
        [31638] = "honor:10328",
        [31637] = "honor:10328",
        [31636] = "honor:6311",
        [31635] = "honor:10328",
        [31634] = "honor:6311",
        [31633] = "honor:10328",
        [31632] = "honor:10328",
        [31631] = "honor:6311",
        [31630] = "honor:10328",
        [31629] = "honor:10328",
        [31628] = "honor:6311",
        [31627] = "honor:10328",
        [31626] = "honor:10328",
        [31625] = "honor:10328",
        [31624] = "honor:6311",
        [31623] = "honor:10328",
        [31622] = "honor:10328",
        [31621] = "honor:6311",
        [31620] = "honor:6311",
        [31619] = "honor:11250",
        [31618] = "honor:10328",
        [31616] = "honor:10328",
        [31614] = "honor:6311",
        [31613] = "honor:10328",
        [31599] = "honor:11794:pvpWarsong:10",
        [31598] = "honor:5897",
        [31597] = "honor:17850:pvpEye:20",
        [31596] = "honor:17850:pvpArathi:20",
        [31595] = "honor:8925",
        [31594] = "honor:8925",
        [31593] = "honor:5164",
        [31592] = "honor:3156",
        [31591] = "honor:5021",
        [31590] = "honor:5021",
        [31589] = "honor:3156",
        [31588] = "honor:10328",
        [31587] = "honor:6311",
        [31586] = "honor:10328",
        [31585] = "honor:10328",
        [31584] = "honor:6311",
        [31413] = "honor:10328",
        [31412] = "honor:11250",
        [31411] = "honor:10328",
        [31410] = "honor:10328",
        [31409] = "honor:6311",
        [31407] = "honor:11250",
        [31406] = "honor:10328",
        [31402] = "money:96000",
        [31400] = "honor:10328",
        [31397] = "honor:6311",
        [31396] = "honor:10328",
        [31392] = "money:192000",
        [31391] = "money:192000",
        [31390] = "money:192000",
        [31379] = "honor:10328",
        [31378] = "honor:11250",
        [31377] = "honor:10328",
        [31376] = "honor:10328",
        [31375] = "honor:6311",
        [31356] = "money:32000",
        [30780] = "BoJ:20",
        [30779] = "BoJ:20",
        [30778] = "BoJ:30",
        [30776] = "BoJ:30",
        [30774] = "BoJ:20",
        [30773] = "BoJ:30",
        [30772] = "BoJ:30",
        [30770] = "BoJ:20",
        [30769] = "BoJ:30",
        [30768] = "BoJ:20",
        [30767] = "BoJ:20",
        [30766] = "BoJ:30",
        [30764] = "BoJ:20",
        [30763] = "BoJ:20",
        [30762] = "BoJ:30",
        [30761] = "BoJ:30",
        [30623] = "money:80000",
        [30498] = "honor:7905",
        [30497] = "honor:7905",
        [30490] = "arena:1500",
        [30489] = "arena:1875",
        [30488] = "arena:1875",
        [30487] = "arena:1125",
        [30486] = "arena:1875",
        [30444] = "money:45000",
        [30443] = "money:72000",
        [30351] = "honor:2000",
        [30350] = "honor:2000",
        [30349] = "honor:4000",
        [30348] = "honor:2000",
        [30346] = "honor:2000",
        [30345] = "honor:2000",
        [30344] = "honor:2000",
        [30343] = "honor:2000",
        [30201] = "honor:10328",
        [30200] = "honor:10328",
        [30188] = "honor:6311",
        [30187] = "honor:10328",
        [30186] = "honor:11250",
        [30183] = "BoJ:15",
        [30156] = "glowcap:1",
        [29721] = "money:96000",
        [29720] = "money:48000",
        [29664] = "money:47500",
        [29617] = "honor:2425:pvpArathi:2",
        [29616] = "honor:3902:pvpAlterac:3",
        [29615] = "honor:4131:pvpArathi:3",
        [29614] = "honor:3902:pvpWarsong:3",
        [29613] = "honor:2525:pvpAlterac:2",
        [29612] = "honor:2425:pvpArathi:2",
        [29611] = "honor:2425:pvpArathi:2",
        [29610] = "honor:3902:pvpAlterac:3",
        [29609] = "honor:4131:pvpArathi:3",
        [29608] = "honor:3902:pvpWarsong:3",
        [29607] = "honor:2525:pvpAlterac:2",
        [29606] = "honor:2425:pvpArathi:2",
        [29605] = "honor:842:pvpArathi:2",
        [29604] = "honor:1300:pvpAlterac:3",
        [29603] = "honor:1301:pvpWarsong:3",
        [29602] = "honor:1377:pvpArathi:3",
        [29601] = "honor:842:pvpArathi:2",
        [29600] = "honor:842:pvpAlterac:2",
        [29599] = "honor:842:pvpArathi:2",
        [29598] = "honor:1300:pvpAlterac:3",
        [29597] = "honor:1301:pvpWarsong:3",
        [29596] = "honor:1377:pvpArathi:3",
        [29595] = "honor:842:pvpAlterac:2",
        [29594] = "honor:842:pvpArathi:2",
        [29593] = "honor:842",
        [29592] = "honor:842",
        [29472] = "pvpAlterac:30:pvpArathi:30:pvpWarsong:30",
        [29471] = "pvpAlterac:30:pvpArathi:30:pvpWarsong:30",
        [29470] = "pvpAlterac:30:pvpArathi:30:pvpWarsong:30",
        [29469] = "pvpAlterac:30:pvpArathi:30:pvpWarsong:30",
        [29468] = "pvpAlterac:30:pvpArathi:30:pvpWarsong:30",
        [29467] = "pvpAlterac:30:pvpArathi:30:pvpWarsong:30",
        [29466] = "pvpAlterac:30:pvpArathi:30:pvpWarsong:30",
        [29465] = "pvpAlterac:30:pvpArathi:30:pvpWarsong:30",
        [29390] = "BoJ:15",
        [29389] = "BoJ:15",
        [29388] = "BoJ:15",
        [29387] = "BoJ:41",
        [29386] = "BoJ:25",
        [29385] = "BoJ:25",
        [29384] = "BoJ:25",
        [29383] = "BoJ:41",
        [29382] = "BoJ:25",
        [29381] = "BoJ:25",
        [29379] = "BoJ:25",
        [29376] = "BoJ:41",
        [29375] = "BoJ:25",
        [29374] = "BoJ:25",
        [29373] = "BoJ:25",
        [29370] = "BoJ:41",
        [29369] = "BoJ:25",
        [29368] = "BoJ:25",
        [29367] = "BoJ:25",
        [29275] = "BoJ:50",
        [29274] = "BoJ:25",
        [29273] = "BoJ:25",
        [29272] = "BoJ:25",
        [29271] = "BoJ:25",
        [29270] = "BoJ:25",
        [29269] = "BoJ:25",
        [29268] = "BoJ:33",
        [29267] = "BoJ:33",
        [29266] = "BoJ:33",
        [29231] = "money:900000",
        [29230] = "money:900000",
        [29229] = "money:900000",
        [29227] = "money:900000",
        [29219] = "money:108000",
        [29218] = "money:108000",
        [29217] = "money:108000",
        [29194] = "money:800000",
        [29192] = "money:800000",
        [29174] = "money:101897",
        [29173] = "money:140762",
        [29172] = "money:632090",
        [29171] = "money:2125454",
        [29170] = "money:632090",
        [29150] = "glowcap:45",
        [29149] = "glowcap:20",
        [29148] = "money:150969",
        [29147] = "money:158775",
        [29146] = "money:175951",
        [29145] = "money:167154",
        [29144] = "money:100000",
        [29143] = "money:100000",
        [29142] = "money:196936",
        [29141] = "money:218003",
        [29140] = "money:130313",
        [29139] = "money:120013",
        [29138] = "money:524391",
        [29137] = "money:496240",
        [29136] = "money:207130",
        [29135] = "money:196078",
        [29105] = "money:950000",
        [29104] = "money:950000",
        [29103] = "money:950000",
        [29102] = "money:950000",
        [29006] = "honor:11794:pvpWarsong:10",
        [29005] = "honor:17850:pvpEye:20",
        [29004] = "honor:17850:pvpArathi:20",
        [29003] = "honor:17850:pvpEye:20",
        [29002] = "honor:11794:pvpWarsong:10",
        [29001] = "honor:17850:pvpArathi:20",
        [29000] = "honor:17850:pvpEye:20",
        [28999] = "honor:11794:pvpWarsong:10",
        [28998] = "honor:17850:pvpArathi:20",
        [28997] = "honor:17850:pvpEye:20",
        [28996] = "honor:11794:pvpWarsong:10",
        [28995] = "honor:17850:pvpArathi:20",
        [28994] = "honor:17850:pvpEye:20",
        [28993] = "honor:17850:pvpArathi:20",
        [28992] = "honor:11794:pvpWarsong:10",
        [28991] = "honor:17850:pvpEye:20",
        [28990] = "honor:17850:pvpArathi:20",
        [28989] = "honor:11794:pvpWarsong:10",
        [28988] = "honor:11794:pvpWarsong:10",
        [28987] = "honor:17850:pvpEye:20",
        [28986] = "honor:17850:pvpArathi:20",
        [28985] = "honor:17850:pvpEye:20",
        [28984] = "honor:11794:pvpWarsong:10",
        [28983] = "honor:17850:pvpArathi:20",
        [28982] = "honor:17850:pvpEye:20",
        [28981] = "honor:11794:pvpWarsong:10",
        [28980] = "honor:17850:pvpArathi:20",
        [28978] = "honor:11794:pvpWarsong:10",
        [28977] = "honor:17850:pvpEye:20",
        [28976] = "honor:17850:pvpArathi:20",
        [28975] = "honor:17850:pvpEye:20",
        [28974] = "honor:17850:pvpArathi:20",
        [28973] = "honor:11794:pvpWarsong:10",
        [28960] = "honor:9563",
        [28959] = "honor:4782:pvpWarsong:3",
        [28957] = "honor:4782",
        [28956] = "honor:4782",
        [28955] = "honor:4782",
        [28954] = "honor:4782",
        [28953] = "honor:4782",
        [28952] = "honor:4782",
        [28951] = "honor:4782",
        [28950] = "honor:4782",
        [28949] = "honor:4782:pvpWarsong:3",
        [28948] = "honor:4782:pvpWarsong:3",
        [28947] = "honor:4782",
        [28946] = "honor:4782",
        [28945] = "honor:4782:pvpWarsong:3",
        [28944] = "honor:4782",
        [28943] = "honor:4782:pvpWarsong:3",
        [28942] = "honor:4782:pvpWarsong:3",
        [28941] = "honor:4782",
        [28940] = "honor:4782",
        [28939] = "honor:9563",
        [28938] = "honor:9563",
        [28937] = "honor:9563",
        [28935] = "honor:19125",
        [28933] = "honor:12750",
        [28931] = "honor:9563",
        [28930] = "honor:9563",
        [28929] = "honor:9563",
        [28928] = "honor:9563",
        [28926] = "honor:9563",
        [28925] = "honor:9563",
        [28924] = "honor:9563",
        [28923] = "honor:19125",
        [28922] = "honor:9563",
        [28921] = "honor:9563",
        [28920] = "honor:9563",
        [28919] = "honor:19125",
        [28918] = "honor:19125",
        [28917] = "honor:19125",
        [28875] = "honor:10328",
        [28874] = "honor:6311",
        [28873] = "honor:10328",
        [28872] = "honor:10328",
        [28871] = "honor:6311",
        [28870] = "honor:5021",
        [28869] = "honor:5164",
        [28868] = "honor:3156",
        [28867] = "honor:5021",
        [28866] = "honor:3156",
        [28865] = "honor:6311",
        [28864] = "honor:10328",
        [28863] = "honor:10328",
        [28862] = "honor:6311",
        [28861] = "honor:10328",
        [28860] = "honor:10328",
        [28859] = "honor:6311",
        [28858] = "honor:10328",
        [28857] = "honor:10328",
        [28856] = "honor:6311",
        [28855] = "honor:6311",
        [28854] = "honor:10328",
        [28853] = "honor:10328",
        [28852] = "honor:6311",
        [28851] = "honor:10328",
        [28850] = "honor:6311",
        [28849] = "honor:10328",
        [28848] = "honor:10328",
        [28847] = "honor:6311",
        [28846] = "honor:10328",
        [28845] = "honor:6311",
        [28844] = "honor:10328",
        [28843] = "honor:10328",
        [28842] = "honor:6311",
        [28841] = "honor:10328",
        [28840] = "honor:10328",
        [28839] = "honor:6311",
        [28838] = "honor:10328",
        [28837] = "honor:10328",
        [28836] = "honor:6311",
        [28835] = "honor:6311",
        [28834] = "honor:10328",
        [28833] = "honor:10328",
        [28832] = "honor:6311",
        [28831] = "honor:10328",
        [28821] = "honor:10328",
        [28820] = "honor:6311",
        [28819] = "honor:10328",
        [28818] = "honor:10328",
        [28817] = "honor:6311",
        [28815] = "honor:10328",
        [28814] = "honor:6311",
        [28813] = "honor:10328",
        [28812] = "honor:10328",
        [28811] = "honor:6311",
        [28809] = "honor:3156",
        [28808] = "honor:5021",
        [28807] = "honor:5021",
        [28806] = "honor:3156",
        [28805] = "honor:5164",
        [28761] = "SpiritShard:18",
        [28760] = "SpiritShard:18",
        [28759] = "SpiritShard:18",
        [28758] = "SpiritShard:18",
        [28724] = "honor:10328",
        [28723] = "honor:5164",
        [28722] = "honor:3156",
        [28721] = "honor:5021",
        [28720] = "honor:5021",
        [28719] = "honor:3156",
        [28718] = "honor:10328",
        [28717] = "honor:10328",
        [28716] = "honor:6311",
        [28715] = "honor:10328",
        [28714] = "honor:6311",
        [28713] = "honor:6311",
        [28712] = "honor:10328",
        [28711] = "honor:10328",
        [28710] = "honor:6311",
        [28709] = "honor:10328",
        [28708] = "honor:10328",
        [28707] = "honor:6311",
        [28706] = "honor:10328",
        [28705] = "honor:10328",
        [28704] = "honor:6311",
        [28703] = "honor:6311",
        [28702] = "honor:10328",
        [28701] = "honor:10328",
        [28700] = "honor:6311",
        [28699] = "honor:10328",
        [28698] = "honor:3156",
        [28697] = "honor:5021",
        [28696] = "honor:5021",
        [28695] = "honor:3156",
        [28694] = "honor:5164",
        [28693] = "honor:3156",
        [28692] = "honor:5021",
        [28691] = "honor:5021",
        [28690] = "honor:3156",
        [28689] = "honor:5164",
        [28688] = "honor:5164",
        [28687] = "honor:3156",
        [28686] = "honor:5021",
        [28685] = "honor:5021",
        [28684] = "honor:3156",
        [28683] = "honor:6311",
        [28681] = "honor:10328",
        [28680] = "honor:6311",
        [28679] = "honor:10328",
        [28646] = "honor:5897",
        [28645] = "honor:8925",
        [28644] = "honor:8925",
        [28643] = "honor:5897",
        [28642] = "honor:8925",
        [28641] = "honor:8925",
        [28640] = "honor:8925",
        [28639] = "honor:8925",
        [28638] = "honor:5897",
        [28632] = "money:48000",
        [28630] = "honor:8925",
        [28629] = "honor:8925",
        [28628] = "honor:20655:pvpArathi:15",
        [28627] = "honor:12622:pvpArathi:10",
        [28626] = "honor:20081:pvpWarsong:15",
        [28625] = "honor:20081:pvpAlterac:15",
        [28624] = "honor:12622:pvpAlterac:10",
        [28623] = "honor:5164",
        [28622] = "honor:3156",
        [28620] = "honor:5021",
        [28619] = "honor:5021",
        [28618] = "honor:3156",
        [28617] = "honor:6311",
        [28616] = "honor:10328",
        [28615] = "honor:10328",
        [28614] = "honor:6311",
        [28613] = "honor:10328",
        [28605] = "honor:5897",
        [28577] = "SpiritShard:18",
        [28576] = "SpiritShard:18",
        [28575] = "SpiritShard:18",
        [28574] = "SpiritShard:18",
        [28561] = "SpiritShard:18",
        [28560] = "SpiritShard:18",
        [28559] = "SpiritShard:18",
        [28557] = "SpiritShard:8",
        [28556] = "SpiritShard:8",
        [28555] = "SpiritShard:50",
        [28553] = "SpiritShard:50",
        [28476] = "honor:19125",
        [28451] = "honor:5897",
        [28450] = "honor:8925",
        [28449] = "honor:8925",
        [28448] = "honor:5897",
        [28447] = "honor:8925",
        [28446] = "honor:8925",
        [28445] = "honor:5897",
        [28444] = "honor:8925",
        [28443] = "honor:8925",
        [28424] = "honor:5897",
        [28423] = "honor:8925",
        [28422] = "honor:8925",
        [28411] = "honor:5897",
        [28410] = "honor:8925",
        [28409] = "honor:8925",
        [28405] = "honor:5897",
        [28404] = "honor:8925",
        [28402] = "honor:8925",
        [28385] = "honor:8925",
        [28383] = "honor:8925",
        [28381] = "honor:5897",
        [28378] = "honor:2949",
        [28377] = "honor:2949",
        [28363] = "honor:4250",
        [28362] = "honor:3445",
        [28358] = "honor:15000",
        [28357] = "honor:5897",
        [28356] = "honor:5897",
        [28355] = "honor:5897",
        [28346] = "honor:9000",
        [28335] = "honor:6311",
        [28334] = "honor:10328",
        [28333] = "honor:11250",
        [28332] = "honor:10328",
        [28331] = "honor:10328",
        [28320] = "honor:5897",
        [28319] = "honor:5897",
        [28314] = "honor:9000",
        [28313] = "honor:14228",
        [28312] = "honor:14228",
        [28310] = "honor:9000",
        [28309] = "honor:9000",
        [28308] = "honor:14228",
        [28307] = "honor:9000",
        [28305] = "honor:14228",
        [28302] = "honor:9000",
        [28300] = "honor:19125",
        [28299] = "honor:19125",
        [28298] = "honor:19125",
        [28297] = "honor:17786",
        [28295] = "honor:14228",
        [28294] = "honor:19125",
        [28293] = "honor:19125",
        [28271] = "money:64000",
        [28247] = "honor:7650",
        [28246] = "honor:7650",
        [28245] = "honor:7650",
        [28244] = "honor:7650",
        [28243] = "honor:2000",
        [28242] = "honor:2000",
        [28241] = "honor:2000",
        [28240] = "honor:2000",
        [28239] = "honor:2000",
        [28238] = "honor:2000",
        [28237] = "honor:2000",
        [28236] = "honor:2000",
        [28235] = "honor:2000",
        [28234] = "honor:2000",
        [28140] = "honor:10328",
        [28139] = "honor:11250",
        [28138] = "honor:10328",
        [28137] = "honor:10328",
        [28136] = "honor:6311",
        [28130] = "honor:10328",
        [28129] = "honor:11250",
        [28128] = "honor:10328",
        [28127] = "honor:10328",
        [28126] = "honor:6311",
        [28123] = "honor:4250",
        [28120] = "honor:3445",
        [28119] = "honor:3445",
        [28118] = "honor:3445",
        [27883] = "honor:11250",
        [27882] = "honor:10328",
        [27881] = "honor:10328",
        [27880] = "honor:6311",
        [27879] = "honor:10328",
        [27711] = "honor:10328",
        [27710] = "honor:11250",
        [27709] = "honor:10328",
        [27708] = "honor:10328",
        [27707] = "honor:6311",
        [27706] = "honor:11250",
        [27705] = "honor:10328",
        [27704] = "honor:10328",
        [27703] = "honor:6311",
        [27702] = "honor:10328",
        [27689] = "glowcap:2",
        [27473] = "honor:11250",
        [27472] = "honor:10328",
        [27471] = "honor:10328",
        [27470] = "honor:6311",
        [27469] = "honor:10328",
        [26001] = "honor:10328",
        [26000] = "honor:6311",
        [25999] = "honor:11250",
        [25998] = "honor:10328",
        [25997] = "honor:10328",
        [25869] = "money:64000",
        [25858] = "honor:10328",
        [25857] = "honor:6311",
        [25856] = "honor:10328",
        [25855] = "honor:10328",
        [25854] = "honor:11250",
        [25838] = "money:181153",
        [25836] = "money:359704",
        [25835] = "money:358386",
        [25834] = "honor:6311",
        [25833] = "honor:10328",
        [25832] = "honor:11250",
        [25831] = "honor:10328",
        [25830] = "honor:10328",
        [25829] = "honor:5738",
        [25828] = "glowcap:15",
        [25827] = "glowcap:25",
        [25743] = "money:114000",
        [25742] = "money:114000",
        [25741] = "money:114000",
        [25737] = "money:112000",
        [25736] = "money:112000",
        [25735] = "money:128000",
        [25550] = "glowcap:1",
        [25548] = "glowcap:1",
        [25526] = "money:48000",
        [24557] = "honor:19125",
        [24556] = "honor:6311",
        [24555] = "honor:10328",
        [24554] = "honor:11250",
        [24553] = "honor:10328",
        [24552] = "honor:10328",
        [24551] = "honor:5738",
        [24550] = "honor:19125",
        [24549] = "honor:6311",
        [24547] = "honor:10328",
        [24546] = "honor:11250",
        [24545] = "honor:10328",
        [24544] = "honor:10328",
        [24539] = "glowcap:2",
        [24429] = "money:6400",
        [24417] = "money:1600",
        [24183] = "money:96000",
        [23814] = "money:48000",
        [23618] = "money:48000",
        [23572] = "BoJ:10",
        [23469] = "honor:4782:pvpArathi:3",
        [23468] = "honor:4782:pvpArathi:3",
        [23467] = "honor:4782:pvpArathi:3",
        [23466] = "honor:4782:pvpArathi:3",
        [23465] = "honor:4782:pvpWarsong:3",
        [23464] = "honor:4782:pvpArathi:3",
        [23456] = "honor:4782:pvpArathi:3",
        [23455] = "honor:4782:pvpWarsong:3",
        [23454] = "honor:4782:pvpArathi:3",
        [23453] = "honor:4782:pvpArathi:3",
        [23452] = "honor:4782:pvpArathi:3",
        [23451] = "honor:4782:pvpArathi:3",
        [23319] = "honor:842:pvpArathi:2",
        [23318] = "honor:1300:pvpAlterac:3",
        [23317] = "honor:842:pvpArathi:2",
        [23316] = "honor:1300:pvpAlterac:3",
        [23315] = "honor:842:pvpArathi:2",
        [23314] = "honor:1300:pvpAlterac:3",
        [23313] = "honor:842:pvpArathi:2",
        [23312] = "honor:1300:pvpAlterac:3",
        [23311] = "honor:842:pvpArathi:2",
        [23310] = "honor:1300:pvpAlterac:3",
        [23309] = "honor:842:pvpArathi:2",
        [23308] = "honor:1300:pvpAlterac:3",
        [23307] = "honor:842:pvpArathi:2",
        [23306] = "honor:1300:pvpAlterac:3",
        [23305] = "honor:1377:pvpArathi:3",
        [23304] = "honor:1301:pvpWarsong:3",
        [23303] = "honor:1377:pvpArathi:3",
        [23302] = "honor:1301:pvpWarsong:3",
        [23301] = "honor:1301:pvpWarsong:3",
        [23300] = "honor:1377:pvpArathi:3",
        [23299] = "honor:1301:pvpWarsong:3",
        [23298] = "honor:1377:pvpArathi:3",
        [23297] = "honor:1377:pvpArathi:3",
        [23296] = "honor:1301:pvpWarsong:3",
        [23295] = "honor:1301:pvpWarsong:3",
        [23294] = "honor:1377:pvpArathi:3",
        [23293] = "honor:1301:pvpWarsong:3",
        [23292] = "honor:1377:pvpArathi:3",
        [23291] = "honor:842:pvpArathi:2",
        [23290] = "honor:842:pvpAlterac:2",
        [23289] = "honor:842:pvpArathi:2",
        [23288] = "honor:842:pvpAlterac:2",
        [23287] = "honor:842:pvpArathi:2",
        [23286] = "honor:842:pvpAlterac:2",
        [23285] = "honor:842:pvpArathi:2",
        [23284] = "honor:842:pvpAlterac:2",
        [23283] = "honor:842:pvpArathi:2",
        [23282] = "honor:842:pvpAlterac:2",
        [23281] = "honor:842:pvpArathi:2",
        [23280] = "honor:842:pvpAlterac:2",
        [23279] = "honor:842:pvpAlterac:2",
        [23278] = "honor:842:pvpArathi:2",
        [23277] = "honor:842:pvpArathi:2",
        [23276] = "honor:1300:pvpAlterac:3",
        [23275] = "honor:842:pvpArathi:2",
        [23274] = "honor:842:pvpAlterac:2",
        [23273] = "honor:1301:pvpWarsong:3",
        [23272] = "honor:1377:pvpArathi:3",
        [23264] = "honor:842:pvpArathi:2",
        [23263] = "honor:1300:pvpAlterac:3",
        [23262] = "honor:842:pvpArathi:2",
        [23261] = "honor:1300:pvpAlterac:3",
        [23260] = "honor:842:pvpArathi:2",
        [23259] = "honor:1300:pvpAlterac:3",
        [23258] = "honor:842:pvpArathi:2",
        [23257] = "honor:1300:pvpAlterac:3",
        [23256] = "honor:842:pvpArathi:2",
        [23255] = "honor:1300:pvpAlterac:3",
        [23254] = "honor:842:pvpArathi:2",
        [23253] = "honor:1300:pvpAlterac:3",
        [23252] = "honor:842:pvpArathi:2",
        [23251] = "honor:1300:pvpAlterac:3",
        [23244] = "honor:1300:pvpAlterac:3",
        [23243] = "honor:842:pvpArathi:2",
        [22922] = "money:80000",
        [22918] = "money:64000",
        [22917] = "money:76000",
        [22916] = "glowcap:25",
        [22906] = "glowcap:30",
        [22887] = "honor:1301:pvpWarsong:3",
        [22886] = "honor:1377:pvpArathi:3",
        [22885] = "honor:1377:pvpArathi:3",
        [22884] = "honor:1377:pvpArathi:3",
        [22883] = "honor:1301:pvpWarsong:3",
        [22882] = "honor:1301:pvpWarsong:3",
        [22881] = "honor:1301:pvpWarsong:3",
        [22880] = "honor:1301:pvpWarsong:3",
        [22879] = "honor:1377:pvpArathi:3",
        [22878] = "honor:1301:pvpWarsong:3",
        [22877] = "honor:1377:pvpArathi:3",
        [22876] = "honor:1377:pvpArathi:3",
        [22875] = "honor:1301:pvpWarsong:3",
        [22874] = "honor:1377:pvpArathi:3",
        [22873] = "honor:1301:pvpWarsong:3",
        [22872] = "honor:1377:pvpArathi:3",
        [22870] = "honor:842:pvpAlterac:2",
        [22869] = "honor:842:pvpAlterac:2",
        [22868] = "honor:842:pvpAlterac:2",
        [22867] = "honor:842:pvpAlterac:2",
        [22865] = "honor:842:pvpAlterac:2",
        [22864] = "honor:842:pvpAlterac:2",
        [22863] = "honor:842:pvpAlterac:2",
        [22862] = "honor:842:pvpAlterac:2",
        [22860] = "honor:842:pvpArathi:2",
        [22859] = "honor:842:pvpArathi:2",
        [22858] = "honor:842:pvpArathi:2",
        [22857] = "honor:842:pvpArathi:2",
        [22856] = "honor:842:pvpArathi:2",
        [22855] = "honor:842:pvpArathi:2",
        [22852] = "honor:842:pvpArathi:2",
        [22843] = "honor:842:pvpArathi:2",
        [22753] = "honor:8925",
        [22752] = "honor:8925",
        [22750] = "honor:8925",
        [22749] = "honor:8925",
        [22748] = "honor:8925",
        [22747] = "honor:8925",
        [22741] = "honor:8925",
        [22740] = "honor:8925",
        [22676] = "honor:8925",
        [22673] = "honor:8925",
        [22672] = "honor:8925",
        [22651] = "honor:8925",
        [21568] = "honor:118:pvpWarsong:3",
        [21567] = "honor:258:pvpWarsong:3",
        [21566] = "honor:118:pvpWarsong:3",
        [21565] = "honor:258:pvpWarsong:3",
        [21563] = "honor:4590:pvpAlterac:2",
        [21120] = "honor:175:pvpArathi:3",
        [21119] = "honor:175:pvpArathi:3",
        [21118] = "honor:258:pvpArathi:3",
        [21117] = "honor:382:pvpArathi:3",
        [21116] = "honor:258:pvpArathi:3",
        [21115] = "honor:382:pvpArathi:3",
        [20444] = "honor:65:pvpWarsong:2",
        [20443] = "honor:214:pvpWarsong:3",
        [20442] = "honor:65:pvpWarsong:2",
        [20441] = "honor:214:pvpWarsong:3",
        [20440] = "honor:214:pvpWarsong:3",
        [20439] = "honor:65:pvpWarsong:2",
        [20438] = "honor:214:pvpWarsong:3",
        [20437] = "honor:214:pvpWarsong:3",
        [20434] = "honor:428",
        [20431] = "honor:65:pvpWarsong:2",
        [20430] = "honor:214:pvpWarsong:3",
        [20429] = "honor:65:pvpWarsong:2",
        [20428] = "honor:65:pvpWarsong:1",
        [20427] = "honor:65:pvpWarsong:1",
        [20426] = "honor:65:pvpWarsong:2",
        [20425] = "honor:428",
        [20244] = "money:1000",
        [20243] = "money:2000",
        [20237] = "money:1500",
        [20235] = "money:1000",
        [20234] = "money:2000",
        [20232] = "money:1500",
        [20227] = "money:1500",
        [20226] = "money:1000",
        [20225] = "money:2000",
        [20224] = "money:1500",
        [20223] = "money:1000",
        [20222] = "money:2000",
        [20220] = "honor:4590:pvpArathi:4",
        [20214] = "honor:2448:pvpArathi:4",
        [20212] = "honor:2525:pvpArathi:4",
        [20211] = "honor:382:pvpArathi:2",
        [20210] = "honor:175:pvpArathi:2",
        [20209] = "honor:258:pvpArathi:2",
        [20208] = "honor:842:pvpArathi:2",
        [20207] = "honor:175:pvpArathi:2",
        [20206] = "honor:258:pvpArathi:2",
        [20205] = "honor:382:pvpArathi:2",
        [20204] = "honor:842:pvpArathi:2",
        [20203] = "honor:2525:pvpArathi:4",
        [20202] = "honor:382:pvpArathi:2",
        [20201] = "honor:175:pvpArathi:2",
        [20200] = "honor:258:pvpArathi:2",
        [20199] = "honor:842:pvpArathi:2",
        [20198] = "honor:258:pvpArathi:2",
        [20197] = "honor:175:pvpArathi:2",
        [20196] = "honor:382:pvpArathi:2",
        [20195] = "honor:842:pvpArathi:2",
        [20194] = "honor:2525:pvpArathi:4",
        [20193] = "honor:382:pvpArathi:2",
        [20192] = "honor:258:pvpArathi:2",
        [20191] = "honor:175:pvpArathi:2",
        [20190] = "honor:842:pvpArathi:2",
        [20189] = "honor:382:pvpArathi:2",
        [20188] = "honor:175:pvpArathi:2",
        [20187] = "honor:258:pvpArathi:2",
        [20186] = "honor:842:pvpArathi:2",
        [20185] = "honor:382:pvpArathi:2",
        [20184] = "honor:2525:pvpArathi:4",
        [20183] = "honor:258:pvpArathi:2",
        [20182] = "honor:175:pvpArathi:2",
        [20181] = "honor:842:pvpArathi:2",
        [20180] = "honor:258:pvpArathi:2",
        [20179] = "honor:382:pvpArathi:2",
        [20178] = "honor:175:pvpArathi:2",
        [20177] = "honor:842:pvpArathi:2",
        [20176] = "honor:2525:pvpArathi:4",
        [20175] = "honor:2525:pvpArathi:4",
        [20174] = "honor:382:pvpArathi:2",
        [20173] = "honor:258:pvpArathi:2",
        [20172] = "honor:175:pvpArathi:2",
        [20171] = "honor:842:pvpArathi:2",
        [20170] = "honor:382:pvpArathi:2",
        [20169] = "honor:175:pvpArathi:2",
        [20168] = "honor:258:pvpArathi:2",
        [20167] = "honor:842:pvpArathi:2",
        [20166] = "honor:258:pvpArathi:2",
        [20165] = "honor:382:pvpArathi:2",
        [20164] = "honor:175:pvpArathi:2",
        [20163] = "honor:842:pvpArathi:2",
        [20162] = "honor:175:pvpArathi:2",
        [20161] = "honor:258:pvpArathi:2",
        [20160] = "honor:382:pvpArathi:2",
        [20159] = "honor:842:pvpArathi:2",
        [20158] = "honor:2525:pvpArathi:4",
        [20157] = "honor:175:pvpArathi:2",
        [20156] = "honor:258:pvpArathi:2",
        [20155] = "honor:382:pvpArathi:2",
        [20154] = "honor:842:pvpArathi:2",
        [20153] = "honor:258:pvpArathi:2",
        [20152] = "honor:175:pvpArathi:2",
        [20151] = "honor:382:pvpArathi:2",
        [20150] = "honor:842:pvpArathi:2",
        [20129] = "honor:175:pvpArathi:2",
        [20128] = "honor:258:pvpArathi:2",
        [20127] = "honor:382:pvpArathi:2",
        [20126] = "honor:175:pvpArathi:2",
        [20125] = "honor:258:pvpArathi:2",
        [20124] = "honor:382:pvpArathi:2",
        [20123] = "honor:175:pvpArathi:2",
        [20122] = "honor:258:pvpArathi:2",
        [20121] = "honor:382:pvpArathi:2",
        [20120] = "honor:175:pvpArathi:2",
        [20119] = "honor:258:pvpArathi:2",
        [20118] = "honor:382:pvpArathi:2",
        [20117] = "honor:175:pvpArathi:2",
        [20116] = "honor:258:pvpArathi:2",
        [20115] = "honor:382:pvpArathi:2",
        [20114] = "honor:175:pvpArathi:2",
        [20113] = "honor:258:pvpArathi:2",
        [20112] = "honor:382:pvpArathi:2",
        [20111] = "honor:175:pvpArathi:2",
        [20110] = "honor:258:pvpArathi:2",
        [20109] = "honor:382:pvpArathi:2",
        [20108] = "honor:175:pvpArathi:2",
        [20107] = "honor:258:pvpArathi:2",
        [20106] = "honor:382:pvpArathi:2",
        [20105] = "honor:175:pvpArathi:2",
        [20104] = "honor:258:pvpArathi:2",
        [20103] = "honor:382:pvpArathi:2",
        [20102] = "honor:175:pvpArathi:2",
        [20101] = "honor:258:pvpArathi:2",
        [20100] = "honor:382:pvpArathi:2",
        [20099] = "honor:175:pvpArathi:2",
        [20098] = "honor:258:pvpArathi:2",
        [20097] = "honor:382:pvpArathi:2",
        [20096] = "honor:175:pvpArathi:2",
        [20095] = "honor:258:pvpArathi:2",
        [20094] = "honor:382:pvpArathi:2",
        [20093] = "honor:175:pvpArathi:2",
        [20092] = "honor:258:pvpArathi:2",
        [20091] = "honor:382:pvpArathi:2",
        [20090] = "honor:175:pvpArathi:2",
        [20089] = "honor:258:pvpArathi:2",
        [20088] = "honor:382:pvpArathi:2",
        [20073] = "honor:1377:pvpArathi:2",
        [20072] = "honor:842:pvpArathi:3",
        [20071] = "honor:842:pvpArathi:3",
        [20070] = "honor:2448:pvpArathi:4",
        [20069] = "honor:4590:pvpArathi:4",
        [20068] = "honor:1377:pvpArathi:2",
        [20061] = "honor:2525:pvpArathi:4",
        [20060] = "honor:2525:pvpArathi:4",
        [20059] = "honor:2525:pvpArathi:4",
        [20058] = "honor:2525:pvpArathi:4",
        [20057] = "honor:2525:pvpArathi:4",
        [20056] = "honor:2525:pvpArathi:4",
        [20055] = "honor:2525:pvpArathi:4",
        [20054] = "honor:842:pvpArathi:2",
        [20053] = "honor:842:pvpArathi:2",
        [20052] = "honor:842:pvpArathi:2",
        [20051] = "honor:842:pvpArathi:2",
        [20050] = "honor:842:pvpArathi:2",
        [20049] = "honor:842:pvpArathi:2",
        [20048] = "honor:842:pvpArathi:2",
        [20047] = "honor:842:pvpArathi:2",
        [20046] = "honor:842:pvpArathi:2",
        [20045] = "honor:842:pvpArathi:2",
        [20044] = "honor:842:pvpArathi:2",
        [20043] = "honor:842:pvpArathi:2",
        [20042] = "honor:842:pvpArathi:2",
        [20041] = "honor:842:pvpArathi:2",
        [19597] = "honor:422",
        [19596] = "honor:624",
        [19595] = "honor:1377:pvpWarsong:2",
        [19590] = "honor:422",
        [19589] = "honor:624",
        [19587] = "honor:1377:pvpWarsong:2",
        [19584] = "honor:422",
        [19583] = "honor:624",
        [19582] = "honor:1377:pvpWarsong:2",
        [19581] = "honor:422",
        [19580] = "honor:624",
        [19578] = "honor:1377:pvpWarsong:2",
        [19573] = "honor:632",
        [19572] = "honor:938",
        [19571] = "honor:1387",
        [19570] = "honor:10200",
        [19569] = "honor:632",
        [19568] = "honor:938",
        [19567] = "honor:1387",
        [19566] = "honor:10200",
        [19565] = "honor:316:pvpWarsong:3",
        [19564] = "honor:469",
        [19563] = "honor:694",
        [19562] = "honor:5100",
        [19561] = "honor:316:pvpWarsong:3",
        [19560] = "honor:469",
        [19559] = "honor:694",
        [19558] = "honor:5100",
        [19557] = "honor:316:pvpWarsong:3",
        [19556] = "honor:469",
        [19555] = "honor:694",
        [19554] = "honor:5100",
        [19553] = "honor:316:pvpWarsong:3",
        [19552] = "honor:469",
        [19551] = "honor:694",
        [19550] = "honor:10200",
        [19549] = "honor:316:pvpWarsong:3",
        [19548] = "honor:469",
        [19547] = "honor:694",
        [19546] = "honor:5100",
        [19545] = "honor:316:pvpWarsong:3",
        [19544] = "honor:469",
        [19543] = "honor:694",
        [19542] = "honor:5100",
        [19541] = "honor:95:pvpWarsong:2",
        [19540] = "honor:141:pvpWarsong:2",
        [19539] = "honor:208:pvpWarsong:2",
        [19538] = "honor:459:pvpWarsong:2",
        [19537] = "honor:95:pvpWarsong:2",
        [19536] = "honor:141:pvpWarsong:2",
        [19535] = "honor:208:pvpWarsong:2",
        [19534] = "honor:459:pvpWarsong:2",
        [19533] = "honor:95:pvpWarsong:1",
        [19532] = "honor:141:pvpWarsong:1",
        [19531] = "honor:208:pvpWarsong:1",
        [19530] = "honor:459:pvpWarsong:1",
        [19529] = "honor:95:pvpWarsong:1",
        [19528] = "honor:141:pvpWarsong:1",
        [19527] = "honor:208:pvpWarsong:1",
        [19526] = "honor:459:pvpWarsong:1",
        [19525] = "honor:95:pvpWarsong:2",
        [19524] = "honor:141:pvpWarsong:2",
        [19523] = "honor:208:pvpWarsong:2",
        [19522] = "honor:459:pvpWarsong:2",
        [19521] = "honor:95:pvpWarsong:2",
        [19520] = "honor:141:pvpWarsong:2",
        [19519] = "honor:208:pvpWarsong:2",
        [19518] = "honor:459:pvpWarsong:2",
        [19517] = "honor:95:pvpWarsong:2",
        [19516] = "honor:208:pvpWarsong:2",
        [19515] = "honor:141:pvpWarsong:2",
        [19514] = "honor:459:pvpWarsong:2",
        [19513] = "honor:95:pvpWarsong:2",
        [19512] = "honor:141:pvpWarsong:2",
        [19511] = "honor:208:pvpWarsong:2",
        [19510] = "honor:459:pvpWarsong:2",
        [19506] = "pvpWarsong:60",
        [19505] = "pvpWarsong:60",
        [19325] = "honor:4590:pvpAlterac:2",
        [19324] = "honor:4760:pvpAlterac:2",
        [19323] = "honor:4760:pvpAlterac:2",
        [19321] = "honor:4760:pvpAlterac:2",
        [19320] = "honor:459:pvpAlterac:1",
        [19319] = "honor:459:pvpAlterac:1",
        [19318] = "money:5000",
        [19317] = "money:6000",
        [19316] = "money:6000",
        [19315] = "honor:4760:pvpAlterac:2",
        [19312] = "honor:4760:pvpAlterac:2",
        [19311] = "honor:4760:pvpAlterac:2",
        [19310] = "honor:4760:pvpAlterac:2",
        [19309] = "honor:4760:pvpAlterac:2",
        [19308] = "honor:4760:pvpAlterac:2",
        [19307] = "money:8000",
        [19301] = "money:7000",
        [19104] = "honor:2380:pvpAlterac:1",
        [19103] = "honor:2380:pvpAlterac:1",
        [19102] = "honor:2720:pvpAlterac:1",
        [19101] = "honor:2720:pvpAlterac:1",
        [19100] = "honor:2380:pvpAlterac:1",
        [19099] = "honor:2380:pvpAlterac:1",
        [19098] = "honor:459:pvpAlterac:2",
        [19097] = "honor:459:pvpAlterac:2",
        [19096] = "honor:459:pvpAlterac:2",
        [19095] = "honor:459:pvpAlterac:2",
        [19094] = "honor:842:pvpAlterac:2",
        [19093] = "honor:842:pvpAlterac:2",
        [19092] = "honor:842:pvpAlterac:2",
        [19091] = "honor:842:pvpAlterac:2",
        [19090] = "honor:842:pvpAlterac:2",
        [19089] = "honor:842:pvpAlterac:2",
        [19088] = "honor:842:pvpAlterac:2",
        [19087] = "honor:842:pvpAlterac:2",
        [19086] = "honor:459:pvpAlterac:1",
        [19085] = "honor:459:pvpAlterac:1",
        [19084] = "honor:459:pvpAlterac:1",
        [19083] = "honor:459:pvpAlterac:1",
        [19068] = "money:1000",
        [19067] = "money:1500",
        [19066] = "money:2000",
        [19062] = "money:1000",
        [19061] = "money:1500",
        [19060] = "money:2000",
        [19046] = "pvpAlterac:30",
        [19045] = "pvpAlterac:30",
        [19032] = "pvpAlterac:60",
        [19031] = "pvpAlterac:60",
        [19030] = "pvpAlterac:50",
        [19029] = "pvpAlterac:50",
        [18877] = "honor:4782:pvpWarsong:3",
        [18876] = "honor:4782:pvpWarsong:3",
        [18874] = "honor:4782:pvpWarsong:3",
        [18873] = "honor:4782:pvpWarsong:3",
        [18871] = "honor:4782:pvpWarsong:3",
        [18869] = "honor:4782:pvpWarsong:3",
        [18868] = "honor:4782:pvpWarsong:3",
        [18867] = "honor:4782:pvpWarsong:3",
        [18866] = "honor:4782:pvpArathi:3",
        [18865] = "honor:4782:pvpArathi:3",
        [18864] = "honor:842",
        [18863] = "honor:842",
        [18862] = "honor:842",
        [18860] = "honor:4782:pvpArathi:3",
        [18859] = "honor:842",
        [18858] = "honor:842",
        [18857] = "honor:842",
        [18856] = "honor:842",
        [18855] = "honor:4782:pvpArathi:3",
        [18854] = "honor:842",
        [18853] = "honor:842",
        [18852] = "honor:842",
        [18851] = "honor:842",
        [18850] = "honor:842",
        [18849] = "honor:842",
        [18848] = "honor:4782:pvpArathi:3",
        [18847] = "honor:4782:pvpArathi:3",
        [18846] = "honor:842",
        [18845] = "honor:842",
        [18844] = "honor:4782:pvpArathi:3",
        [18843] = "honor:4782:pvpArathi:3",
        [18841] = "money:900:honor:1",
        [18840] = "honor:4782:pvpArathi:3",
        [18839] = "money:900:honor:1",
        [18838] = "honor:4782:pvpArathi:3",
        [18837] = "honor:4782:pvpArathi:3",
        [18836] = "honor:4782:pvpArathi:3",
        [18835] = "honor:4782:pvpArathi:3",
        [18834] = "honor:842",
        [18833] = "honor:4782:pvpArathi:3",
        [18831] = "honor:4782:pvpWarsong:3",
        [18830] = "honor:4782:pvpWarsong:3",
        [18828] = "honor:4782:pvpArathi:3",
        [18827] = "honor:4782:pvpArathi:3",
        [18826] = "honor:4782:pvpArathi:3",
        [18825] = "honor:4782:pvpArathi:3",
        [18607] = "honor:7650",
        [18606] = "honor:7650",
        [18461] = "honor:459:pvpArathi:1",
        [18457] = "honor:208:pvpWarsong:1",
        [18456] = "honor:459:pvpWarsong:1",
        [18455] = "honor:208:pvpWarsong:1",
        [18454] = "honor:459:pvpWarsong:1",
        [18453] = "honor:208:pvpWarsong:1",
        [18452] = "honor:459:pvpWarsong:1",
        [18449] = "honor:208:pvpWarsong:1",
        [18448] = "honor:459:pvpWarsong:1",
        [18447] = "honor:208:pvpWarsong:1",
        [18445] = "honor:459:pvpWarsong:1",
        [18444] = "honor:208:pvpWarsong:2",
        [18443] = "honor:459:pvpWarsong:2",
        [18442] = "honor:95:pvpWarsong:2",
        [18441] = "honor:208:pvpArathi:1",
        [18440] = "honor:95:pvpArathi:1",
        [18437] = "honor:208:pvpWarsong:1",
        [18436] = "honor:208:pvpWarsong:1",
        [18435] = "honor:208:pvpWarsong:1",
        [18434] = "honor:459:pvpWarsong:1",
        [18432] = "honor:208:pvpWarsong:1",
        [18430] = "honor:208:pvpWarsong:1",
        [18429] = "honor:459:pvpWarsong:1",
        [18428] = "honor:208:pvpWarsong:2",
        [18427] = "honor:95:pvpArathi:1",
        [17625] = "honor:3902:pvpWarsong:3",
        [17624] = "honor:4131:pvpArathi:3",
        [17623] = "honor:3902:pvpAlterac:3",
        [17622] = "honor:2425:pvpArathi:2",
        [17620] = "honor:2525:pvpAlterac:2",
        [17618] = "honor:2425:pvpArathi:2",
        [17608] = "honor:2525:pvpAlterac:2",
        [17607] = "honor:2425:pvpArathi:2",
        [17605] = "honor:4131:pvpArathi:3",
        [17604] = "honor:2425:pvpArathi:2",
        [17603] = "honor:3902:pvpWarsong:3",
        [17602] = "honor:3902:pvpAlterac:3",
        [17593] = "honor:3902:pvpWarsong:3",
        [17592] = "honor:4131:pvpArathi:3",
        [17591] = "honor:3902:pvpAlterac:3",
        [17590] = "honor:2425:pvpArathi:2",
        [17588] = "honor:2525:pvpAlterac:2",
        [17586] = "honor:2425:pvpArathi:2",
        [17584] = "honor:2525:pvpAlterac:2",
        [17583] = "honor:2425:pvpArathi:2",
        [17581] = "honor:4131:pvpArathi:3",
        [17580] = "honor:2425:pvpArathi:2",
        [17579] = "honor:3902:pvpWarsong:3",
        [17578] = "honor:3902:pvpAlterac:3",
        [17352] = "money:500",
        [17351] = "money:1000",
        [17349] = "money:500",
        [17348] = "money:1000",
        [16580] = "honor:2425:pvpArathi:2",
        [16579] = "honor:3902:pvpWarsong:3",
        [16578] = "honor:3902:pvpAlterac:3",
        [16577] = "honor:4131:pvpArathi:3",
        [16574] = "honor:2525:pvpAlterac:2",
        [16573] = "honor:2425:pvpArathi:2",
        [16571] = "honor:2525:pvpAlterac:2",
        [16569] = "honor:2425:pvpArathi:2",
        [16568] = "honor:2425:pvpArathi:2",
        [16567] = "honor:3902:pvpWarsong:3",
        [16566] = "honor:3902:pvpAlterac:3",
        [16565] = "honor:4131:pvpArathi:3",
        [16564] = "honor:3902:pvpWarsong:3",
        [16563] = "honor:4131:pvpArathi:3",
        [16562] = "honor:2425:pvpArathi:2",
        [16561] = "honor:3902:pvpAlterac:3",
        [16560] = "honor:2525:pvpAlterac:2",
        [16558] = "honor:2425:pvpArathi:2",
        [16555] = "honor:2525:pvpAlterac:2",
        [16554] = "honor:2425:pvpArathi:2",
        [16552] = "honor:3902:pvpWarsong:3",
        [16551] = "honor:2425:pvpArathi:2",
        [16550] = "honor:3902:pvpAlterac:3",
        [16549] = "honor:4131:pvpArathi:3",
        [16548] = "honor:2525:pvpAlterac:2",
        [16545] = "honor:2425:pvpArathi:2",
        [16544] = "honor:2425:pvpArathi:2",
        [16543] = "honor:3902:pvpWarsong:3",
        [16542] = "honor:3902:pvpAlterac:3",
        [16541] = "honor:4131:pvpArathi:3",
        [16540] = "honor:2525:pvpAlterac:2",
        [16539] = "honor:2425:pvpArathi:2",
        [16536] = "honor:2425:pvpArathi:2",
        [16535] = "honor:4131:pvpArathi:3",
        [16534] = "honor:3902:pvpWarsong:3",
        [16533] = "honor:3902:pvpAlterac:3",
        [16532] = "honor:459:pvpWarsong:1",
        [16497] = "honor:459:pvpWarsong:1",
        [16486] = "honor:459:pvpWarsong:1",
        [16484] = "honor:2525:pvpAlterac:2",
        [16483] = "honor:2425:pvpArathi:2",
        [16480] = "honor:2425:pvpArathi:2",
        [16479] = "honor:3902:pvpWarsong:3",
        [16478] = "honor:3902:pvpAlterac:3",
        [16477] = "honor:4131:pvpArathi:3",
        [16476] = "honor:2425:pvpArathi:2",
        [16475] = "honor:3902:pvpWarsong:3",
        [16474] = "honor:3902:pvpAlterac:3",
        [16473] = "honor:4131:pvpArathi:3",
        [16472] = "honor:2425:pvpArathi:2",
        [16471] = "honor:2525:pvpAlterac:2",
        [16468] = "honor:2425:pvpArathi:2",
        [16467] = "honor:3902:pvpWarsong:3",
        [16466] = "honor:4131:pvpArathi:3",
        [16465] = "honor:3902:pvpAlterac:3",
        [16463] = "honor:2525:pvpAlterac:2",
        [16462] = "honor:2425:pvpArathi:2",
        [16459] = "honor:2425:pvpArathi:2",
        [16457] = "honor:2425:pvpArathi:2",
        [16456] = "honor:3902:pvpWarsong:3",
        [16455] = "honor:3902:pvpAlterac:3",
        [16454] = "honor:2525:pvpAlterac:2",
        [16453] = "honor:4131:pvpArathi:3",
        [16452] = "honor:4131:pvpArathi:3",
        [16451] = "honor:3902:pvpAlterac:3",
        [16450] = "honor:3902:pvpWarsong:3",
        [16449] = "honor:2425:pvpArathi:2",
        [16448] = "honor:2525:pvpAlterac:2",
        [16446] = "honor:2425:pvpArathi:2",
        [16444] = "honor:2425:pvpArathi:2",
        [16443] = "honor:4131:pvpArathi:3",
        [16442] = "honor:3902:pvpWarsong:3",
        [16441] = "honor:3902:pvpAlterac:3",
        [16440] = "honor:2525:pvpAlterac:2",
        [16437] = "honor:2425:pvpArathi:2",
        [16345] = "honor:4782:pvpArathi:3",
        [16342] = "honor:459:pvpArathi:1",
        [16341] = "honor:208:pvpArathi:1",
        [16335] = "honor:459:pvpWarsong:2",
        [15200] = "honor:95:pvpWarsong:2",
        [15199] = "pvpAlterac:20:pvpArathi:20:pvpWarsong:20",
        [15198] = "pvpAlterac:20:pvpArathi:20:pvpWarsong:20",
        [15197] = "pvpArathi:3:pvpWarsong:3",
        [15196] = "pvpArathi:3:pvpWarsong:3",
        [12584] = "honor:4782:pvpArathi:3",
    }
end

if AtlasLoot:GameVersion_GE(AtlasLoot.WRATH_VERSION_NUM) then
    VENDOR_PRICES_AUTO_RAW.WRATH = {

    }
end

-- own changes here, this table use VENDOR_PRICES_AUTO as fallback
local VENDOR_PRICES, VENDOR_PRICES_RAW = AtlasLoot:GetGameVersionDataTable()
VENDOR_PRICES_RAW.CLASSIC = {

}

if AtlasLoot:GameVersion_GE(AtlasLoot.BC_VERSION_NUM) then
    VENDOR_PRICES_AUTO_RAW.BCC = {
        -- P5 Badge Adds
        [32228] = "BoJ:15", --Epic Gem - Added in Phase 5 to Vendor
        [32249] = "BoJ:15", --Epic Gem - Added in Phase 5 to Vendor
        [32231] = "BoJ:15", --Epic Gem - Added in Phase 5 to Vendor
        [32230] = "BoJ:15", --Epic Gem - Added in Phase 5 to Vendor
        [32227] = "BoJ:15", --Epic Gem - Added in Phase 5 to Vendor
        [32229] = "BoJ:15", --Epic Gem - Added in Phase 5 to Vendor
        [34949] = "BoJ:45", --P5 Badge item
        [34952] = "BoJ:45", --P5 Badge item
        [34894] = "BoJ:105", --P5 Badge item
        [34893] = "BoJ:105", --P5 Badge item
        [34891] = "BoJ:150", --P5 Badge item
        [34892] = "BoJ:150", --P5 Badge item
        [34895] = "BoJ:150", --P5 Badge item
        [34896] = "BoJ:150", --P5 Badge item
        [34898] = "BoJ:150", --P5 Badge item
        [34951] = "BoJ:45", --P5 Badge item
        [34950] = "BoJ:45", --P5 Badge item
        [34887] = "BoJ:60", --P5 Badge item
        [34890] = "BoJ:60", --P5 Badge item
        [34889] = "BoJ:60", --P5 Badge item
        [34888] = "BoJ:60", --P5 Badge item
        [34926] = "BoJ:75", --P5 Badge item
        [34919] = "BoJ:75", --P5 Badge item
        [34938] = "BoJ:75", --P5 Badge item
        [34924] = "BoJ:100", --P5 Badge item
        [34917] = "BoJ:100", --P5 Badge item
        [34936] = "BoJ:100", --P5 Badge item
        [34925] = "BoJ:100", --P5 Badge item
        [34918] = "BoJ:100", --P5 Badge item
        [34937] = "BoJ:100", --P5 Badge item
        [34911] = "BoJ:75", --P5 Badge item
        [34902] = "BoJ:75", --P5 Badge item
        [34904] = "BoJ:75", --P5 Badge item
        [34929] = "BoJ:75", --P5 Badge item
        [34906] = "BoJ:100", --P5 Badge item
        [34903] = "BoJ:100", --P5 Badge item
        [34927] = "BoJ:100", --P5 Badge item
        [34900] = "BoJ:100", --P5 Badge item
        [34905] = "BoJ:100", --P5 Badge item
        [34901] = "BoJ:100", --P5 Badge item
        [34910] = "BoJ:100", --P5 Badge item
        [34928] = "BoJ:100", --P5 Badge item
        [34916] = "BoJ:75", --P5 Badge item
        [34932] = "BoJ:75", --P5 Badge item
        [34935] = "BoJ:75", --P5 Badge item
        [34930] = "BoJ:100", --P5 Badge item
        [34933] = "BoJ:100", --P5 Badge item
        [34912] = "BoJ:100", --P5 Badge item
        [34914] = "BoJ:100", --P5 Badge item
        [34931] = "BoJ:100", --P5 Badge item
        [34934] = "BoJ:100", --P5 Badge item
        [34947] = "BoJ:75", --P5 Badge item
        [34944] = "BoJ:75", --P5 Badge item
        [34941] = "BoJ:75", --P5 Badge item
        [34923] = "BoJ:75", --P5 Badge item
        [34942] = "BoJ:100", --P5 Badge item
        [34939] = "BoJ:100", --P5 Badge item
        [34921] = "BoJ:100", --P5 Badge item
        [34945] = "BoJ:100", --P5 Badge item
        [34922] = "BoJ:100", --P5 Badge item
        [34946] = "BoJ:100", --P5 Badge item
        [34943] = "BoJ:100", --P5 Badge item
        [34940] = "BoJ:100", --P5 Badge item
        [35321] = "BoJ:60", --P5 Badge item
        [33484] = "BoJ:60", --P5 Badge item
        [33593] = "BoJ:35", --P5 Badge item
        [33304] = "BoJ:60", --P5 Badge item
        [33333] = "BoJ:60", --P5 Badge item
        [35324] = "BoJ:60", --P5 Badge item
        [33585] = "BoJ:75", --P5 Badge item
        [33584] = "BoJ:75", --P5 Badge item
        [33586] = "BoJ:60", --P5 Badge item
        [33587] = "BoJ:60", --P5 Badge item
        [33588] = "BoJ:35", --P5 Badge item
        [33291] = "BoJ:60", --P5 Badge item
        [33973] = "BoJ:60", --P5 Badge item
        [33972] = "BoJ:75", --P5 Badge item
        [33974] = "BoJ:60", --P5 Badge item
        [33504] = "BoJ:20", --P5 Badge item
        [33502] = "BoJ:20", --P5 Badge item
        [33324] = "BoJ:60", --P5 Badge item
        [33529] = "BoJ:35", --P5 Badge item
        [33537] = "BoJ:60", --P5 Badge item
        [33965] = "BoJ:75", --P5 Badge item
        [33970] = "BoJ:60", --P5 Badge item
        [33527] = "BoJ:75", --P5 Badge item
        [33528] = "BoJ:60", --P5 Badge item
        [33386] = "BoJ:60", --P5 Badge item
        [33530] = "BoJ:75", --P5 Badge item
        [33280] = "BoJ:60", --P5 Badge item
        [33531] = "BoJ:60", --P5 Badge item
        [33534] = "BoJ:60", --P5 Badge item
        [33536] = "BoJ:60", --P5 Badge item
        [33532] = "BoJ:35", --P5 Badge item
        [33535] = "BoJ:35", --P5 Badge item
        [33334] = "BoJ:35", --P5 Badge item
        [33325] = "BoJ:35", --P5 Badge item
        [33523] = "BoJ:60", --P5 Badge item
        [33516] = "BoJ:35", --P5 Badge item
        [33524] = "BoJ:60", --P5 Badge item
        [33331] = "BoJ:60", --P5 Badge item
        [33522] = "BoJ:75", --P5 Badge item
        [33514] = "BoJ:60", --P5 Badge item
        [33515] = "BoJ:75", --P5 Badge item
        [33513] = "BoJ:35", --P5 Badge item
        [33517] = "BoJ:60", --P5 Badge item
        [33810] = "BoJ:75", --P5 Badge item
        [33279] = "BoJ:60", --P5 Badge item
        [33501] = "BoJ:75", --P5 Badge item
        [33207] = "BoJ:60", --P5 Badge item
        [33520] = "BoJ:35", --P5 Badge item
        [33518] = "BoJ:75", --P5 Badge item
        [33512] = "BoJ:60", --P5 Badge item
        [33519] = "BoJ:60", --P5 Badge item
        [33192] = "BoJ:25", --P5 Badge item
        -- ZA Badge Gear Adds
        [33588] = "BoJ:35", -- ZA Badge Item
        [33586] = "BoJ:60", -- ZA Badge Item
        [33291] = "BoJ:60", -- ZA Badge Item
        [33584] = "BoJ:75", -- ZA Badge Item
        [33589] = "BoJ:35", -- ZA Badge Item
        [33587] = "BoJ:60", -- ZA Badge Item
        [33585] = "BoJ:75", -- ZA Badge Item
        [33972] = "BoJ:75", -- ZA Badge Item
        [33973] = "BoJ:60", -- ZA Badge Item
        [33566] = "BoJ:75", -- ZA Badge Item
        [33578] = "BoJ:35", -- ZA Badge Item
        [33974] = "BoJ:60", -- ZA Badge Item
        [33559] = "BoJ:60", -- ZA Badge Item
        [33577] = "BoJ:60", -- ZA Badge Item
        [33579] = "BoJ:75", -- ZA Badge Item
        [33580] = "BoJ:35", -- ZA Badge Item
        [33540] = "BoJ:35", -- ZA Badge Item
        [33539] = "BoJ:60", -- ZA Badge Item
        [33583] = "BoJ:60", -- ZA Badge Item
        [33538] = "BoJ:75", -- ZA Badge Item
        [33582] = "BoJ:60", -- ZA Badge Item
        [33222] = "BoJ:60", -- ZA Badge Item
        [33287] = "BoJ:60", -- ZA Badge Item
        [33557] = "BoJ:35", -- ZA Badge Item
        [33552] = "BoJ:75", -- ZA Badge Item
        [33970] = "BoJ:60", -- ZA Badge Item
        [33965] = "BoJ:75", -- ZA Badge Item
        [33535] = "BoJ:35", -- ZA Badge Item
        [33524] = "BoJ:60", -- ZA Badge Item
        [33536] = "BoJ:60", -- ZA Badge Item
        [33537] = "BoJ:60", -- ZA Badge Item
        [33529] = "BoJ:35", -- ZA Badge Item
        [33528] = "BoJ:60", -- ZA Badge Item
        [33280] = "BoJ:60", -- ZA Badge Item
        [33527] = "BoJ:75", -- ZA Badge Item
        [33532] = "BoJ:35", -- ZA Badge Item
        [33531] = "BoJ:60", -- ZA Badge Item
        [33386] = "BoJ:60", -- ZA Badge Item
        [33530] = "BoJ:75", -- ZA Badge Item
        [33324] = "BoJ:60", -- ZA Badge Item
        [33810] = "BoJ:75", -- ZA Badge Item
        [33514] = "BoJ:60", -- ZA Badge Item
        [33513] = "BoJ:35", -- ZA Badge Item
        [33331] = "BoJ:60", -- ZA Badge Item
        [33512] = "BoJ:60", -- ZA Badge Item
        [33501] = "BoJ:75", -- ZA Badge Item
        [33520] = "BoJ:35", -- ZA Badge Item
        [33519] = "BoJ:60", -- ZA Badge Item
        [33518] = "BoJ:75", -- ZA Badge Item
        [33207] = "BoJ:60", -- ZA Badge Item
        [33522] = "BoJ:75", -- ZA Badge Item
        [33516] = "BoJ:35", -- ZA Badge Item
        [33517] = "BoJ:60", -- ZA Badge Item
        [33279] = "BoJ:60", -- ZA Badge Item
        [33524] = "BoJ:60", -- ZA Badge Item
        [33515] = "BoJ:75", -- ZA Badge Item
        [33523] = "BoJ:60", -- ZA Badge Item
        [33334] = "BoJ:35", -- ZA Badge Item
        [33192] = "BoJ:25", -- ZA Badge Item
        [33296] = "BoJ:35", -- ZA Badge Item
        [33325] = "BoJ:35", -- ZA Badge Item
        [33593] = "BoJ:35", -- ZA Badge Item
        [33510] = "BoJ:20", -- ZA Badge Item
        [33509] = "BoJ:20", -- ZA Badge Item
        [33508] = "BoJ:20", -- ZA Badge Item
        [33503] = "BoJ:20", -- ZA Badge Item
        [33502] = "BoJ:20", -- ZA Badge Item
        [33506] = "BoJ:20", -- ZA Badge Item
        [33507] = "BoJ:20", -- ZA Badge Item
        [33505] = "BoJ:20", -- ZA Badge Item
        [35321] = "BoJ:60", -- ZA Badge Item
        [33304] = "BoJ:60", -- ZA Badge Item
        [33484] = "BoJ:60", -- ZA Badge Item
        [35324] = "BoJ:60", -- ZA Badge Item
        [33333] = "BoJ:60", -- ZA Badge Item
        [35327] = "honor:30000:pvpAlterac:20", --P4 PVP item Battlemaster's Alacrity
        [34579] = "honor:30000:pvpAlterac:20", --P4 PVP item Battlemaster's Audacity
        [34576] = "honor:30000:pvpAlterac:20", --P4 PVP item Battlemaster's Cruelty
        [34577] = "honor:30000:pvpAlterac:20", --P4 PVP item Battlemaster's Depravity
        [34578] = "honor:30000:pvpAlterac:20", --P4 PVP item Battlemaster's Determination
        [34580] = "honor:30000:pvpAlterac:20", --P4 PVP item Battlemaster's Perserverance
        [35326] = "BoJ:75", --P4 Badge item Battlemaster's Alacrity
        [34049] = "BoJ:75", --P4 Badge item Battlemaster's Audacity
        [34163] = "BoJ:75", --P4 Badge item Battlemaster's Cruelty
        [34162] = "BoJ:75", --P4 Badge item Battlemaster's Depravity
        [33832] = "BoJ:75", --P4 Badge item Battlemaster's Determination
        [34050] = "BoJ:75", --P4 Badge item Battlemaster's Perserverance
        --[[
        [34399] = "sunmote:1:34233:1", -- Robes of Ghostly Hatred
        [34397] = "sunmote:1:34211:1", -- Bladed Chaos Tunic
        [34398] = "sunmote:1:34212:1", -- Utopian Tunic of Elune
        [34396] = "sunmote:1:34229:1", -- Garments of Crashing Shores
        [34394] = "sunmote:1:34215:1", -- Breastplate of Agony's Aversion
        [34395] = "sunmote:1:34216:1", -- Noble Judicator's Chestguard
        [34406] = "sunmote:1:34342:1", -- Gloves of Tyri's Power
        [34408] = "sunmote:1:34234:1", -- Gloves of the Forest Drifter
        [34407] = "sunmote:1:34351:1", -- Tranquil Moonlight Wraps
        [34409] = "sunmote:1:34350:1", -- Gauntlets of the Ancient Frostwolf
        [34405] = "sunmote:1:34339:1", -- Helm of Arcane Purity
        [34403] = "sunmote:1:34245:1", -- Cover of Ursoc the Mighty
        [34404] = "sunmote:1:34244:1", -- Mask of the Fury Hunter
        [34402] = "sunmote:1:34332:1", -- Shroud of Chieftain Ner'zhul
        [34400] = "sunmote:1:34345:1", -- Crown of Dath'Remar
        [34401] = "sunmote:1:34243:1", -- Helm of Uther's Resolve
        [34386] = "sunmote:1:34170:1", -- Pantaloons of Growing Strife
        [34384] = "sunmote:1:34169:1", -- Breeches of Natural Splendor
        [34385] = "sunmote:1:34188:1", -- Leggings of the Immortal Beast
        [34383] = "sunmote:1:34186:1", -- Kilt of Spiritual Reconstruction
        [34381] = "sunmote:1:34180:1", -- Felstrength Legplates
        [34382] = "sunmote:1:34167:1", -- Judicator's Legguards
        [34393] = "sunmote:1:34202:1", -- Shoulderpads of Knowledge's Pursuit
        [34392] = "sunmote:1:34195:1", -- Demontooth Shoulderpads
        [34391] = "sunmote:1:34209:1", -- Spaulders of Devastation
        [34390] = "sunmote:1:34208:1", -- Erupting Epaulets
        [34388] = "sunmote:1:34192:1", -- Pauldrons of Berserking
        [34389] = "sunmote:1:34193:1", -- Spaulders of the Thalassian Defender
        ]]--
    }
end

if AtlasLoot:GameVersion_GE(AtlasLoot.WRATH_VERSION_NUM) then
    VENDOR_PRICES_AUTO_RAW.WRATH = {

    }
end

setmetatable(VENDOR_PRICES, {__index = VENDOR_PRICES_AUTO})

local function GetItemPriceString(itemID)
    return AtlasLoot.dbGlobal.VendorPrice[itemID] or VENDOR_PRICES_AUTO[itemID] or VENDOR_PRICES[itemID]
end

function VendorPrice.ItemHasVendorPrice(itemID)
    return GetItemPriceString(itemID) ~= nil
end

function VendorPrice.GetVendorPriceForItem(itemID)
    return GetItemPriceString(itemID)
end

function VendorPrice.GetPriceInfoList()
    return PRICE_INFO_LIST
end

--################################
-- Vendor scan
--################################
local VendorLockList = {}
local SourcesAddon
local UnitGUID, GetMerchantNumItems, GetMerchantItemID, GetMerchantItemCostInfo, GetMerchantItemCostItem, GetItemInfoInstant =
      UnitGUID, GetMerchantNumItems, GetMerchantItemID, GetMerchantItemCostInfo, GetMerchantItemCostItem, GetItemInfoInstant

local function GetNpcIDFromGuid(guid)
	local npcID = select(6,strsplit("-",guid))
	if npcID then
		return tonumber(npcID)
	end
end

function VendorPrice.ScanShownVendor()
    local targetGUID = UnitGUID("target")
    if not targetGUID then return end
    local npcID = GetNpcIDFromGuid(targetGUID)
    if not npcID or VendorLockList[npcID] then return end
    if not SourcesAddon then SourcesAddon = AtlasLoot.Addons:GetAddon("Sources") end

    for itemNum = 1, GetMerchantNumItems() do
        local vItemID = GetMerchantItemID(itemNum)
        local itemCost = ""
        for costNum = 1, GetMerchantItemCostInfo(itemNum) do
            local itemTexture, itemValue, itemLink, currencyName = GetMerchantItemCostItem(itemNum, costNum)
            if itemLink then
                local costItemID = GetItemInfoInstant(itemLink)
                local formatString
                if VENDOR_PRICE_FORMAT[costItemID] then
                    formatString = VENDOR_PRICE_FORMAT[costItemID]
                elseif VENDOR_PRICE_FORMAT[itemTexture] then
                    formatString = VENDOR_PRICE_FORMAT[itemTexture]
                else
                    break -- end here as there is a unknown currency
                end
                if formatString then
                    if itemCost == "" then
                        itemCost = format(formatString, itemValue or 0)
                    else
                        itemCost = itemCost..":"..format(formatString, itemValue or 0)
                    end
                end
            end
        end

        if itemCost ~= "" then
            AtlasLoot.dbGlobal.VendorPrice[vItemID] = itemCost
        end
        if SourcesAddon then
            SourcesAddon:ItemSourcesUpdated(vItemID)
        end
    end

    VendorLockList[npcID] = true
end

VendorPrice.EventFrame = CreateFrame("FRAME")
local function EventFrame_OnEvent(frame, event, arg1, arg2)
	if event == "MERCHANT_SHOW" then
		VendorPrice.ScanShownVendor()
	end
end
VendorPrice.EventFrame:SetScript("OnEvent", EventFrame_OnEvent)
VendorPrice.EventFrame:RegisterEvent("MERCHANT_SHOW")

